/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  Data Application Unit Measurements
 *  VXIpnp Instrument Driver
 *****************************************************************************/

#ifndef __RSCMWDAU_HEADER
#define __RSCMWDAU_HEADER

#include "rscore.h"
#include "rscmwdau_attributes.h"
#include "rscmwdau_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <limits.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSCMWDAU_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWDAU_CLASS_DRIVER_PREFIX                ""
#define RSCMWDAU_CLASS_DRIVER_VENDOR                ""
#define RSCMWDAU_CLASS_DRIVER_REVISION              ""
#define RSCMWDAU_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWDAU_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWDAU_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWDAU_SPECIFIC_DRIVER_PREFIX             "RSCMWDAU"
#define RSCMWDAU_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWDAU_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWDAU_MAJOR_VERSION                      3L    /* Instrument driver major version          */
#define RSCMWDAU_MINOR_VERSION                      7L    /* Instrument driver minor version          */
#define RSCMWDAU_MINOR_MINOR_VERSION                510L   /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSCMWDAU_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSCMWDAU_GROUP_CAPABILITIES                 ""
#define RSCMWDAU_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWDAU_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWDAU_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWDAU_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWDAU_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMWDAU_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWDAU_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWDAU_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWDAU_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWDAU_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWDAU_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWDAU_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWDAU_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMWDAU_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWDAU_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWDAU_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWDAU_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWDAU_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWDAU_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMWDAU_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMWDAU_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWDAU_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWDAU_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWDAU_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWDAU_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWDAU_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMWDAU_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWDAU_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWDAU_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWDAU_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMWDAU_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMWDAU_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWDAU_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWDAU_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMWDAU_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWDAU_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSCMWDAU_ATTR_DAU_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSCMWDAU_ATTR_SERVICE_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSCMWDAU_ATTR_IMS_SERVICE_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSCMWDAU_ATTR_SERVICE_EXTERNAL_CONNECTION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSCMWDAU_ATTR_SERVICE_IPV6_SUPPORT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSCMWDAU_ATTR_LAN_STATUS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 322
#define RSCMWDAU_ATTR_MTU                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSCMWDAU_ATTR_IPV4_ADDRESS_SETUP_MODE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWDAU_ATTR_IPV4_IP_ADDRESS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWDAU_ATTR_IPV4_SUBNET_MASK                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSCMWDAU_ATTR_IPV4_GATEWAY_ADDRESS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWDAU_ATTR_IPV4_ADDRESS_ADD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWDAU_ATTR_IPV4_ADDRESS_DELETE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWDAU_ATTR_IPV4_QUERY_IP_ADDRESS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSCMWDAU_ATTR_IPV4_QUERY_SUBNET_MASK                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSCMWDAU_ATTR_IPV4_QUERY_GATEWAY_ADDRESS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSCMWDAU_ATTR_IPV4_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSCMWDAU_ATTR_IPV6_ADDRESS_SETUP_MODE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSCMWDAU_ATTR_IPV6_STATIC_ADDRESS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSCMWDAU_ATTR_IPV6_STATIC_DEFAULT_ROUTER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSCMWDAU_ATTR_IPV6_QUERY_STATIC_ADDRESS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSCMWDAU_ATTR_IPV6_QUERY_STATIC_DEFAULT_ROUTER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSCMWDAU_ATTR_IPV6_MOBILE_PREFIX_SETUP_MODE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSCMWDAU_ATTR_IPV6_PREFIX_POOL_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 342
#define RSCMWDAU_ATTR_IPV6_PREFIX_ADD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSCMWDAU_ATTR_IPV6_PREFIX_DELETE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSCMWDAU_ATTR_IPV6_PREFIX_DELETE_BY_INDEX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSCMWDAU_ATTR_IPV6_ROUTING_SETUP_MODE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSCMWDAU_ATTR_IPV6_ROUTING_DELETE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSCMWDAU_ATTR_IPV6_ROUTING_DELETE_BY_INDEX                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSCMWDAU_ATTR_IPV6_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSCMWDAU_ATTR_IPV6_ADDRESS_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSCMWDAU_ATTR_DNS_SERVER_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSCMWDAU_ATTR_DNS_QUERY_IP_ADDRESS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSCMWDAU_ATTR_DNS_SERVER_FOREIGN_ADDRESS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSCMWDAU_ATTR_DNS_SERVER_USE_DHCP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSCMWDAU_ATTR_DNS_ENTRY_DELETE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSCMWDAU_ATTR_APPLICATION_ENTRY_DELETE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSCMWDAU_ATTR_DNS_DOMAIN_TEST                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSCMWDAU_ATTR_DNS_DOMAIN_TEST_START                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSCMWDAU_ATTR_DNS_SERVER_RESPONSE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSCMWDAU_ATTR_FTP_SERVICE_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSCMWDAU_ATTR_FTP_ANONYMOUS_USER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSCMWDAU_ATTR_FTP_DATA_UPLOAD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSCMWDAU_ATTR_IMS_QUERY_STATUS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 343
#define RSCMWDAU_ATTR_IMS_QUERY_MOBILE_STATUS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 344
#define RSCMWDAU_ATTR_IMS_QUERY_ADVANCED_MOBILE_STATUS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345
#define RSCMWDAU_ATTR_IMS_QUERY_MOBILE_IP_ADDRESS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346
#define RSCMWDAU_ATTR_IMS_QUERY_MOBILE_PUBLIC_USER_ID                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347
#define RSCMWDAU_ATTR_IMS_QUERY_MOBILE_PRIVATE_USER_ID                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348
#define RSCMWDAU_ATTR_IMS_QUERY_MOBILE_HOME_DOMAIN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349
#define RSCMWDAU_ATTR_IMS_QUERY_PCSCF_ADDRESS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350
#define RSCMWDAU_ATTR_IMS_SERVER_USAGE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351
#define RSCMWDAU_ATTR_IMS_ADVANCED_SERVER_USAGE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352
#define RSCMWDAU_ATTR_IMS_INTERN_ADDRESS_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353
#define RSCMWDAU_ATTR_IMS_ADVANCED_INTERN_ADDRESS_TYPE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 354
#define RSCMWDAU_ATTR_IMS_EXTERN_IP_ADDRESS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355
#define RSCMWDAU_ATTR_IMS_EXTERN_IPV4_ADDRESS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356
#define RSCMWDAU_ATTR_IMS_EXTERN_IPV6_ADDRESS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_PRIVATE_USER_ID                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_ALGORITHM                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_KEY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_RAND                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_AMF                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_AKA_VERSION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 364
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_RES_LENGTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 365
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_KEY_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 366
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_OPC                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 367
#define RSCMWDAU_ATTR_IMS_AUTHENTICATION_OP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 368
#define RSCMWDAU_ATTR_IMS_DEREGISTER_MOBILE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 369
#define RSCMWDAU_ATTR_ADVANCED_IMS_DEREGISTER_MOBILE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 370
#define RSCMWDAU_ATTR_IMS_IP_SEC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 371
#define RSCMWDAU_ATTR_IMS_IP_SEC_INTEGRITY_ALGORITHM                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 372
#define RSCMWDAU_ATTR_IMS_IP_SEC_ENCRYPTION_ALGORITHM                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 373
#define RSCMWDAU_ATTR_IMS_VOICE_PRECONDITIONS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 374
#define RSCMWDAU_ATTR_IMS_VOICE_AUDIOROUTING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 375
#define RSCMWDAU_ATTR_IMS_VOICE_LOOPBACK                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 376
#define RSCMWDAU_ATTR_IMS_VOICE_MEDIA_ENDPOINT_IP_ADDRESS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 377
#define RSCMWDAU_ATTR_IMS_VOICE_MEDIA_ENDPOINT_PORT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 378
#define RSCMWDAU_ATTR_IMS_VOICE_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 379
#define RSCMWDAU_ATTR_IMS_VOICE_AMR_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 380
#define RSCMWDAU_ATTR_IMS_VOICE_CODEC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 381
#define RSCMWDAU_ATTR_IMS_VOICE_VIDEO_CODEC                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 382
#define RSCMWDAU_ATTR_IMS_VOICE_CALL_ESTABLISH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 383
#define RSCMWDAU_ATTR_IMS_VOICE_CALL_DISCONNECT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 384
#define RSCMWDAU_ATTR_IMS_QUERY_VOICE_CALL_STATUS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 385
#define RSCMWDAU_ATTR_IMS_SMS_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 386
#define RSCMWDAU_ATTR_IMS_SMS_TEXT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 387
#define RSCMWDAU_ATTR_IMS_QUERY_SMS_STATUS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 388
#define RSCMWDAU_ATTR_IMS_CLEAN_GENERAL_INFO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 389
#define RSCMWDAU_ATTR_IMS_TCP_KEEP_ALIVE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 390
#define RSCMWDAU_ATTR_IMS_SIP_TIMER_SELECTION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 391
#define RSCMWDAU_ATTR_IMS_SIP_TIMER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 392
#define RSCMWDAU_ATTR_IMS_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSCMWDAU_ATTR_IMS_TRANSPORT_SELECTION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSCMWDAU_ATTR_CREATE_PCSCF_TAB                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 149
#define RSCMWDAU_ATTR_DELETE_PCSCF_TAB                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 150
#define RSCMWDAU_ATTR_UPDATE_PCSCF_PROFILES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 151
#define RSCMWDAU_ATTR_PCSCF_IP_ADDRESS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 152
#define RSCMWDAU_ATTR_PCSCF_BEHAVIOR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSCMWDAU_ATTR_PCSCF_FAILURE_CODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 154
#define RSCMWDAU_ATTR_PCSCF_RETRY_AFTER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 155
#define RSCMWDAU_ATTR_CREATE_SUBSCRIBER_TAB                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 156
#define RSCMWDAU_ATTR_DELETE_SUBSCRIBER_TAB                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 157
#define RSCMWDAU_ATTR_UPDATE_SUBSCRIBER_PROFILE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 158
#define RSCMWDAU_ATTR_SUBSCRIBER_PRIVATE_USER_ID                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSCMWDAU_ATTR_SUBSCRIBER_AUTHENTICATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSCMWDAU_ATTR_SUBSCRIBER_KEY_GENERATION_ALGORITHM                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSCMWDAU_ATTR_SUBSCRIBER_AUTHENTICATION_KEY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSCMWDAU_ATTR_SUBSCRIBER_AUTHENTICATION_MANAGEMENT_FIELD            RS_SPECIFIC_PUBLIC_ATTR_BASE + 163
#define RSCMWDAU_ATTR_SUBSCRIBER_OPC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSCMWDAU_ATTR_SUBSCRIBER_RES_LENGTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSCMWDAU_ATTR_SUBSCRIBER_IPSEC_ENABLE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSCMWDAU_ATTR_SUBSCRIBER_INTEGRITY_ALGORITHM                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSCMWDAU_ATTR_SUBSCRIBER_ENCRYPTION_ALGORITHM                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSCMWDAU_ATTR_SUBSCRIBER_PUBLIC_USER_ID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSCMWDAU_ATTR_SUBSCRIBER_QCI                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSCMWDAU_ATTR_SUBSCRIBER_PAU_HEADER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 324
#define RSCMWDAU_ATTR_CREATE_VIRTUAL_SUBSCRIBER_PROFILE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSCMWDAU_ATTR_DELETE_VIRTUAL_SUBSCRIBER_PROFILE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSCMWDAU_ATTR_UPDATE_VIRTUAL_SUBSCRIBER_PROFILE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 172
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_PUBLIC_USER_ID                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_BEHAVIOR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_SIGNALING_TYPE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_CODEC_VIDEO                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_VIDEO_ATTRIBUTES                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MEDIA_ENDPOINT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_AMR_VOICE_CODEC                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_AMR_ALIGNMENT_MODE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_AMR_CODEC_RATES                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MTC_DESTINATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 182
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MTC_CALL_TYPE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MTC_SIGNAL_TYPE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MTC_AMR_TYPE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MTC_AMR_ALIGNMENT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MTC_AMR_CODEC_RATES                RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MTC_AMR_VIDEO_CODEC                RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_MTC_AMR_VIDEO_ATTRIBUTES           RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSCMWDAU_ATTR_INITIATE_VIRTUAL_SUBSCRIBER_VOICE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_SMS_DESTINATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_SMS_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_SMS_TEXT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_SMS_ENCODING                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_GROUP_CHAT_ADD_PARTICIPANT         RS_SPECIFIC_PUBLIC_ATTR_BASE + 393
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_GROUP_CHAT_DELETE_PARTICIPANT      RS_SPECIFIC_PUBLIC_ATTR_BASE + 394
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_GROUP_CHAT_PARTICIPANTS_CSV        RS_SPECIFIC_PUBLIC_ATTR_BASE + 395
#define RSCMWDAU_ATTR_SEND_VIRTUAL_SUBSCRIBER_SMS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBED_SMS_SELECTED_FILE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 298
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_START_MODE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_HF_ONLY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_DTX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_DTX_RECV                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_RATE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_CONFIGURATION_MODE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_BANDWIDTH_COMMON               RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_BANDWIDTH_SEND                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 251
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_BANDWIDTH_RECEIVE              RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_CMR                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_CHAW                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_EVS_IO_MODE_CONFIG                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 325
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_BEARER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_AUDIO_CODEC                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FORCE_CODEC                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FILE_TRANSFER_DESTINATION_LIST     RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FILE_TRANSFER_DESTINATION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 258
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FILE_TRANSFER_TYPE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FILE_TRANSFER_CHUNK_SIZE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FILE_TRANSFER_FILE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FILE_TRANSFER_INITIATE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_PCAP_FILE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FEATURE_VIDEO_CALL                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FEATURE_STANDALONE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FEATURE_SESSION_MODE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSCMWDAU_ATTR_VIRTUAL_SUBSCRIBER_FEATURE_FILE_TRANSFER              RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSCMWDAU_ATTR_INITIATE_UPDATE_CALL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSCMWDAU_ATTR_UPDATE_CALL_ID                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSCMWDAU_ATTR_UPDATE_CALL_AMR_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSCMWDAU_ATTR_UPDATE_CALL_AMR_ALIGNMENT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSCMWDAU_ATTR_UPDATE_CALL_CODEC_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSCMWDAU_ATTR_UPDATE_CALL_VIDEO_CODEC                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSCMWDAU_ATTR_UPDATE_CALL_AUDIO_CODEC                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define RSCMWDAU_ATTR_UPDATE_CALL_VIDEO_ATTRIBUTES                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSCMWDAU_ATTR_UPDATE_CALL_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSCMWDAU_ATTR_UPDATE_CALL_IDS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSCMWDAU_ATTR_UPDATE_CALL_EVENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_START_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 264
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_HF_ONLY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 265
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_DTX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 266
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_DTX_RECV                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_RATE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_CONFIGURATION_MODE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 269
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_BANDWIDTH_COMMON                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_BANDWIDTH_SEND                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_BANDWIDTH_RECEIVE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_CMR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSCMWDAU_ATTR_UPDATE_CALL_EVS_CHAW                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSCMWDAU_ATTR_UPDATE_CALL_INBAND_AMR_BITRATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define RSCMWDAU_ATTR_UPDATE_CALL_INBAND_AMRWB_BITRATE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 307
#define RSCMWDAU_ATTR_UPDATE_CALL_INBAND_EVS_BANDWIDTH                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 308
#define RSCMWDAU_ATTR_UPDATE_CALL_INBAND_EVS_BITRATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 309
#define RSCMWDAU_ATTR_UPDATE_CALL_INBAND_REPETITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 310
#define RSCMWDAU_ATTR_UPDATE_CALL_INBAND_PERFORM_CALL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 311
#define RSCMWDAU_ATTR_UPDATE_CHAT_TEXT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 312
#define RSCMWDAU_ATTR_INITIATE_UPDATE_CHAT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 313
#define RSCMWDAU_ATTR_SEND_UPDATE_CHAT_ACTIVE_NOTIFICATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 314
#define RSCMWDAU_ATTR_SEND_UPDATE_CHAT_IDLE_NOTIFICATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSCMWDAU_ATTR_EPDG_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 316
#define RSCMWDAU_ATTR_EPDG_IPV4_ADDRESS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSCMWDAU_ATTR_EPDG_IPV6_ADDRESS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSCMWDAU_ATTR_EPDG_ID_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSCMWDAU_ATTR_EPDG_ID_VALUE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSCMWDAU_ATTR_EPDG_IKE_ENCRYPTION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSCMWDAU_ATTR_EPDG_IKE_PRF                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSCMWDAU_ATTR_EPDG_IKE_INTEGRITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSCMWDAU_ATTR_EPDG_DIFFIE_HELLMAN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSCMWDAU_ATTR_EPDG_ESP_ENCRYPTION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSCMWDAU_ATTR_EPDG_ESP_INTEGRITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSCMWDAU_ATTR_EPDG_DEAD_PEER_DETECTION_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 317
#define RSCMWDAU_ATTR_EPDG_DEAD_PEER_DETECTION_INTERVAL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSCMWDAU_ATTR_EPDG_DEAD_PEER_DETECTION_TIMEOUT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSCMWDAU_ATTR_EPDG_SSL_ENABLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSCMWDAU_ATTR_EPDG_SERVER_KEY_FILE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSCMWDAU_ATTR_EPDG_SERVER_CERTIFICATE_FILE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSCMWDAU_ATTR_EPDG_IMSI                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSCMWDAU_ATTR_EPDG_PCSCF_IKEV2_AUTO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 331
#define RSCMWDAU_ATTR_EPDG_AUTHENTICATION_ALGORITHM                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSCMWDAU_ATTR_EPDG_AUTHENTICATION_DATA_KEY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSCMWDAU_ATTR_EPDG_AUTHENTICATION_RAND                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 222
#define RSCMWDAU_ATTR_EPDG_AUTHENTICATION_AMF                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSCMWDAU_ATTR_EPDG_AUTHENTICATION_KEY_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSCMWDAU_ATTR_EPDG_AUTHENTICATION_OPC                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 225
#define RSCMWDAU_ATTR_EPDG_CLEARS_EVENT_LOG                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 326
#define RSCMWDAU_ATTR_APPLICATION_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSCMWDAU_ATTR_RAN_TECHNOLOGY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSCMWDAU_ATTR_RAN_ASSIGN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSCMWDAU_ATTR_RAN_UPLINK_TRACE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSCMWDAU_ATTR_RAN_DOWNLINK_TRACE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 278
#define RSCMWDAU_ATTR_PING_DESTINATION_ADDRESS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSCMWDAU_ATTR_PING_INTERVAL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSCMWDAU_ATTR_PING_PAYLOAD_SIZE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSCMWDAU_ATTR_PING_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSCMWDAU_ATTR_PING_TIMEOUT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSCMWDAU_ATTR_THROUGHPUT_MEASUREMENT_POINTS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSCMWDAU_ATTR_THROUGHPUT_QUERY_MEASUREMENT_INTERVAL                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSCMWDAU_ATTR_THROUGHPUT_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 279
#define RSCMWDAU_ATTR_THROUGHPUT_MAX_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 318
#define RSCMWDAU_ATTR_DNS_REQUESTS_MAX_INDEX_COUNT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 319
#define RSCMWDAU_ATTR_IP_LOGGING_INTERFACE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSCMWDAU_ATTR_IP_LOGGING_FILE_SIZE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSCMWDAU_ATTR_IP_LOGGING_PACKET_COUNTER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSCMWDAU_ATTR_IP_LOGGING_PACKET_SNAP_LENGTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 320
#define RSCMWDAU_ATTR_IP_LOGGING_LOG_FILE_NAME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSCMWDAU_ATTR_IPERF_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSCMWDAU_ATTR_IPERF_TEST_DURATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSCMWDAU_ATTR_IPERF_PROTOCOL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSCMWDAU_ATTR_IPERF_PORT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSCMWDAU_ATTR_IPERF_SOCKET_BUFFER_SIZE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 396
#define RSCMWDAU_ATTR_IPERF_CLIENT_DESTINATION_ADDRESS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSCMWDAU_ATTR_IPERF_CLIENT_PARALLEL_CONNECTIONS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSCMWDAU_ATTR_IPERF_CLIENT_MAX_BIT_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSCMWDAU_ATTR_IPERF_CLIENT_REVERSE_MODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 397
#define RSCMWDAU_ATTR_IPERF_NAT_PARALLEL_CONNECTIONS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 398
#define RSCMWDAU_ATTR_IPERF_NAT_MAX_BIT_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 399
#define RSCMWDAU_ATTR_IPERF_PACKET_SIZE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSCMWDAU_ATTR_IPERF_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 280
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_ENABLE_SET                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_IP_ADDRESS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_DELAY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_JITTER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_REORDERING_RATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_PACKETLOSS_RATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_DUPLICATES_RATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_CORRUPTION_RATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSCMWDAU_ATTR_NETWORK_IMPAIRMENTS_JITTER_DISTRIBUTION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSCMWDAU_ATTR_IP_ANALYSIS_RESULT_TCP_ANALYSIS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSCMWDAU_ATTR_IP_ANALYSIS_RESULT_IP_CONNECT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSCMWDAU_ATTR_IP_ANALYSIS_RESULT_DPCP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSCMWDAU_ATTR_IP_ANALYSIS_RESULT_FT_TRIGGER                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSCMWDAU_ATTR_IP_ANALYSIS_RESULT_VOICE_OVER_IMS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSCMWDAU_ATTR_IP_ANALYSIS_TCP_TRESHOLD_WINDOW                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSCMWDAU_ATTR_IP_ANALYSIS_TCP_TRESHOLD_RETRANSMISSIONS              RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSCMWDAU_ATTR_IP_ANALYSIS_TCP_THRESHOLD_ROUND_TRIP_TIME             RS_SPECIFIC_PUBLIC_ATTR_BASE + 321
#define RSCMWDAU_ATTR_IP_ANALYSIS_TCP_TRESHOLD_OVERHEAD                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSCMWDAU_ATTR_FT_TRIGGER_ASSIGN_CONNECTION_TO_TRACE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSCMWDAU_ATTR_IP_ANALYSIS_APPLICATION_SELECTED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSCMWDAU_ATTR_IP_ANALYSIS_LAYER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSCMWDAU_ATTR_IP_ANALYSIS_STORE_DB                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSCMWDAU_ATTR_IP_ANALYSIS_PORT_SCAN_CLEAR_EVENT_LOG                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 332
#define RSCMWDAU_ATTR_IP_ANALYSIS_PORT_SCAN_DESTINATION_IP                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 333
#define RSCMWDAU_ATTR_IP_ANALYSIS_PORT_SCAN_LAYER_4_PROTOCOL                RS_SPECIFIC_PUBLIC_ATTR_BASE + 334
#define RSCMWDAU_ATTR_IP_ANALYSIS_PORT_SCAN_TIMEOUT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 335
#define RSCMWDAU_ATTR_IP_ANALYSIS_PORT_SCAN_INITIATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 336
#define RSCMWDAU_ATTR_IP_ANALYSIS_PORT_SCAN_ABORT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define RSCMWDAU_ATTR_IP_ANALYSIS_PORT_SCAN_STATUS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 338
#define RSCMWDAU_ATTR_IP_ANALYSIS_PORT_SCAN_EXPORT_FILE_PATH                RS_SPECIFIC_PUBLIC_ATTR_BASE + 339
#define RSCMWDAU_ATTR_IP_ANALYSIS_FLOW_FILTER_CONNECTIONS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 340
#define RSCMWDAU_ATTR_IP_ANALYSIS_KEYWORD_IMPORT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 341
#define RSCMWDAU_ATTR_IP_ANALYSIS_KEYWORD_ADD                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 327
#define RSCMWDAU_ATTR_IP_ANALYSIS_KEYWORD_DELETE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 328
#define RSCMWDAU_ATTR_IP_ANALYSIS_KEYWORD_SEARCH_LIST                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 329
#define RSCMWDAU_ATTR_IP_REPLAY_REMOVE_FROM_PLAYLIST                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSCMWDAU_ATTR_IP_REPLAY_PLAYLIST_START                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSCMWDAU_ATTR_IP_REPLAY_PLAYLIST_STOP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSCMWDAU_ATTR_QUERY_IP_REPLAY_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSCMWDAU_ATTR_AUDIO_DELAY_MAXIMUM_SAMPLES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 226
#define RSCMWDAU_ATTR_QUERY_AUDIO_DELAY_INTERVAL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 227
#define RSCMWDAU_ATTR_QUERY_AUDIO_DELAY_SAMPLE_INTERVAL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 228
#define RSCMWDAU_ATTR_QOS_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define RSCMWDAU_ATTR_QOS_ADD_FILTER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSCMWDAU_ATTR_QOS_FILTER_CATALOG                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 283
#define RSCMWDAU_ATTR_QOS_REMOVE_FILTER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 284
#define RSCMWDAU_ATTR_QOS_PROFILE_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 285
#define RSCMWDAU_ATTR_QOS_PROFILE_IP_ADDRESS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 286
#define RSCMWDAU_ATTR_QOS_PROFILE_PROTOCOL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 287
#define RSCMWDAU_ATTR_QOS_PROFILE_TCP_PRIORIZATION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 288
#define RSCMWDAU_ATTR_QOS_PROFILE_HOP_LIMIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 289
#define RSCMWDAU_ATTR_QOS_PROFILE_PACKET_LOSS_RATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 290
#define RSCMWDAU_ATTR_QOS_PROFILE_DELAY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 291
#define RSCMWDAU_ATTR_QOS_PROFILE_JITTER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 292
#define RSCMWDAU_ATTR_QOS_PROFILE_JITTER_DISTRIBUTION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 293
#define RSCMWDAU_ATTR_QOS_PROFILE_REORDER_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 294
#define RSCMWDAU_ATTR_QOS_PROFILE_DUPLICATE_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 295
#define RSCMWDAU_ATTR_QOS_PROFILE_CORRUPT_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 296
#define RSCMWDAU_ATTR_QOS_PROFILE_BIT_RATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 297
#define RSCMWDAU_ATTR_DATA_APPLIACTION_MEASUREMENT_INIT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSCMWDAU_ATTR_DATA_APPLIACTION_MEASUREMENT_ABORT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSCMWDAU_ATTR_DATA_APPLIACTION_MEASUREMENT_STOP                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSCMWDAU_ATTR_DATA_APPLICATION_MEASUREMENT_AUDIO_DELAY_INIT         RS_SPECIFIC_PUBLIC_ATTR_BASE + 229
#define RSCMWDAU_ATTR_DATA_APPLICATION_MEASUREMENT_AUDIO_DELAY_ABORT        RS_SPECIFIC_PUBLIC_ATTR_BASE + 230
#define RSCMWDAU_ATTR_DATA_APPLICATION_MEASUREMENT_AUDIO_DELAY_STOP         RS_SPECIFIC_PUBLIC_ATTR_BASE + 231
#define RSCMWDAU_ATTR_QUERY_PING_NO_REPLY_COUNT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSCMWDAU_ATTR_QUERY_DNS_REQUESTS_COUNT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSCMWDAU_ATTR_QUERY_SECURITY_APPLICATIONS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 330
#define RSCMWDAU_ATTR_SYSTEM_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSCMWDAU_ATTR_SYSTEM_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSCMWDAU_ATTR_SYSTEM_ALL_ERRORS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSCMWDAU_ATTR_SYSTEM_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSCMWDAU_ATTR_ID_QUERY_RESPONSE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSCMWDAU_ATTR_IPV4_DNS_ADDRESS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 8

// rscmwdau_rngIPv4AddressSetupMode
#define RSCMWDAU_VAL_IPV4_ADDRESS_AUTO                                      0
#define RSCMWDAU_VAL_IPV4_ADDRESS_STATIC                                    1
#define RSCMWDAU_VAL_IPV4_ADDRESS_LAN_DAU                                   2

// rscmwdau_rngIPv6AddressSetupMode
#define RSCMWDAU_VAL_IPV6_ADDRESS_AUTO                                      0
#define RSCMWDAU_VAL_IPV6_ADDRESS_STAT                                      1
#define RSCMWDAU_VAL_IPV6_ADDRESS_ACONF                                     2

// rscmwdau_rngServiceState
#define RSCMWDAU_VAL_SERVICE_OFF                                            0
#define RSCMWDAU_VAL_SERVICE_ON                                             1
#define RSCMWDAU_VAL_SERVICE_PENDING                                        2
#define RSCMWDAU_VAL_SERVICE_ADJ                                            3
#define RSCMWDAU_VAL_SERVICE_AUT                                            4
#define RSCMWDAU_VAL_SERVICE_COUP                                           5
#define RSCMWDAU_VAL_SERVICE_INV                                            6

// rscmwdau_rngFTPServiceType
#define RSCMWDAU_VAL_FTP_SERVER                                             0
#define RSCMWDAU_VAL_FTP_TRAFFIC_GEN                                        1

// rscmwdau_rngIPerfProtocol
#define RSCMWDAU_VAL_IPERF_PROTOCOL_UDP                                     0
#define RSCMWDAU_VAL_IPERF_PROTOCOL_TCP                                     1

// rscmwdau_rngIPv6MobilePrefixSetupMode
#define RSCMWDAU_VAL_IPV6_PREFIX_STAT                                       0
#define RSCMWDAU_VAL_IPV6_PREFIX_DHCP                                       1

// rscmwdau_rngIPv6RoutingSetupMode
#define RSCMWDAU_VAL_IPV6_ROUTING_MANUAL                                    0

// rscmwdau_rngDNSServerType
#define RSCMWDAU_VAL_DNS_NONE                                               0
#define RSCMWDAU_VAL_DNS_INTERNAL                                           1
#define RSCMWDAU_VAL_DNS_INTERNAL_FOREIGN                                   2
#define RSCMWDAU_VAL_DNS_FOREIGN                                            3

// rscmwdau_rngIMSQueryStatus
#define RSCMWDAU_VAL_IMS_OFF                                                0
#define RSCMWDAU_VAL_IMS_RUNNING                                            1
#define RSCMWDAU_VAL_IMS_ERROR                                              2

// rscmwdau_rngIMSQueryMobileStatus
#define RSCMWDAU_VAL_IMS_MOBILE_UNREGISTERED                                0
#define RSCMWDAU_VAL_IMS_MOBILE_REGISTERED                                  1
#define RSCMWDAU_VAL_IMS_MOBILE_EMERGENCY                                   2
#define RSCMWDAU_VAL_IMS_MOBILE_EXPIRED                                     3
#define RSCMWDAU_VAL_IMS_MOBILE_TERMINATED                                  4

// rscmwdau_rngIMSServerUsage
#define RSCMWDAU_VAL_IMS_SERVER_USAGE_INTERN                                0
#define RSCMWDAU_VAL_IMS_SERVER_USAGE_EXTERN                                1

// rscmwdau_rngIMSInternAddressType
#define RSCMWDAU_VAL_IMS_ADDRESS_TYPE_IPV4                                  0
#define RSCMWDAU_VAL_IMS_ADDRESS_TYPE_IPV6                                  1

// rscmwdau_rngIMSAuthenticationAlgorith
#define RSCMWDAU_VAL_IMS_AUTH_ALGORITHM_XOR                                 0
#define RSCMWDAU_VAL_IMS_AUTH_ALGORITHM_MILENAGE                            1

// rscmwdau_rngIMSAuthenticationAKAVersion
#define RSCMWDAU_VAL_IMS_AKA_VERSION_1                                      0
#define RSCMWDAU_VAL_IMS_AKA_VERSION_2                                      1
#define RSCMWDAU_VAL_IMS_HTTP                                               2

// rscmwdau_rngIMSAuthenticationKeyType
#define RSCMWDAU_VAL_IMS_KEY_TYPE_OPC                                       0
#define RSCMWDAU_VAL_IMS_KEY_TYPE_OP                                        1

// rscmwdau_rngIMSIPSecIntegrityAlgorithm
#define RSCMWDAU_VAL_IMS_IP_SEC_HMMD                                        0
#define RSCMWDAU_VAL_IMS_IP_SEC_HMSH                                        1

// rscmwdau_rngIMSIPSecEncryptionAlgorithm
#define RSCMWDAU_VAL_IMS_ENCRYPTION_DES                                     0
#define RSCMWDAU_VAL_IMS_ENCRYPTION_AES                                     1
#define RSCMWDAU_VAL_IMS_ENCRYPTION_NO_ENC                                  2

// rscmwdau_rngIMSVoicePreconditions
#define RSCMWDAU_VAL_IMS_VOICE_WITH_PRECONDITIONS                           0
#define RSCMWDAU_VAL_IMS_VOICE_WITHOUT_PRECONDITIONS                        1
#define RSCMWDAU_VAL_IMS_VOICE_SIMPLE_PRECONDITIONS                         2

// rscmwdau_rngIMSVoiceType
#define RSCMWDAU_VAL_IMS_VOICE_TYPE_AUDIO                                   0
#define RSCMWDAU_VAL_IMS_VOICE_TYPE_VIDEO                                   1

// rscmwdau_rngIMSVoiceAMRType
#define RSCMWDAU_VAL_IMS_VOICE_AMR_NARROWBAND                               0
#define RSCMWDAU_VAL_IMS_VOICE_AMR_WIDEBAND                                 1
#define RSCMWDAU_VAL_IMS_VOICE_AMR_EVS                                      2

// rscmwdau_rngIMSVoiceVideoCodec
#define RSCMWDAU_VAL_IMS_VIDEO_CODEC_H263                                   0
#define RSCMWDAU_VAL_IMS_VIDEO_CODEC_H264                                   1

// rscmwdau_rngIMSQueryVoiceCallStatus
#define RSCMWDAU_VAL_IMS_CALL_STATUS_NO_ACTION                              0
#define RSCMWDAU_VAL_IMS_CALL_STATUS_CALLING                                1
#define RSCMWDAU_VAL_IMS_CALL_STATUS_RELEASED                               2
#define RSCMWDAU_VAL_IMS_CALL_STATUS_CALL_ESTAB                             3
#define RSCMWDAU_VAL_IMS_CALL_STATUS_NO_RESPONSE                            4
#define RSCMWDAU_VAL_IMS_CALL_STATUS_RINGING                                5
#define RSCMWDAU_VAL_IMS_CALL_STATUS_INVALID                                -1

// rscmwdau_rngIMSSMSType
#define RSCMWDAU_VAL_IMS_SMS_TYPE_3GPP                                      0
#define RSCMWDAU_VAL_IMS_SMS_TYPE_3GPP2                                     1

// rscmwdau_rngIMSQuerySMSStatus
#define RSCMWDAU_VAL_IMS_SMS_STATUS_INV                                     -1
#define RSCMWDAU_VAL_IMS_SMS_STATUS_NONE                                    0
#define RSCMWDAU_VAL_IMS_SMS_STATUS_SIPR                                    1
#define RSCMWDAU_VAL_IMS_SMS_STATUS_SCOM                                    2
#define RSCMWDAU_VAL_IMS_SMS_STATUS_SFAIL                                   3

// rscmwdau_rngIPLoggingInterface
#define RSCMWDAU_VAL_IP_LOGGING_INTERFACE_IP                                0
#define RSCMWDAU_VAL_IP_LOGGING_INTERFACE_PPP                               1
#define RSCMWDAU_VAL_IP_LOGGING_INTERFACE_LAN_DAU                           2
#define RSCMWDAU_VAL_IP_LOGGING_INTERFACE_UPM                               3
#define RSCMWDAU_VAL_IP_LOGGING_INTERFACE_UIPC                              4

// rscmwdau_rngNetworkImpairmentsJitterDistribution
#define RSCMWDAU_VAL_JITTER_DISTR_UNIFORM                                   0
#define RSCMWDAU_VAL_JITTER_DISTR_NORMAL                                    1
#define RSCMWDAU_VAL_JITTER_DISTR_PARETO                                    2
#define RSCMWDAU_VAL_JITTER_DISTR_PARETO_NORMAL                             3

// rscmwdau_rngIMSVoiceAudiorouting
#define RSCMWDAU_VAL_AUDIO_ROUTING_AUDIOBOARD                               0
#define RSCMWDAU_VAL_AUDIO_ROUTING_LOOPBACK                                 1
#define RSCMWDAU_VAL_AUDIO_ROUTING_FORWARD                                  2

// rscmwdau_rngIPAnalysisLayer
#define RSCMWDAU_VAL_IP_ANALYSIS_LAYER_FEATURE                              0
#define RSCMWDAU_VAL_IP_ANALYSIS_LAYER_APP                                  1
#define RSCMWDAU_VAL_IP_ANALYSIS_LAYER_L7                                   2
#define RSCMWDAU_VAL_IP_ANALYSIS_LAYER_L4                                   3
#define RSCMWDAU_VAL_IP_ANALYSIS_LAYER_L3                                   4

// rscmwdau_rngIPReplayState
#define RSCMWDAU_VAL_IP_REPLAY_STATE_OFF                                    0
#define RSCMWDAU_VAL_IP_REPLAY_STATE_RUN                                    1
#define RSCMWDAU_VAL_IP_REPLAY_STATE_RDY                                    2

// rscmwdau_rngSubscriberAuthentication
#define RSCMWDAU_VAL_NO_AUTHENTICATION                                      0
#define RSCMWDAU_VAL_AUTHENTICATION_AKA_V1                                  1
#define RSCMWDAU_VAL_AUTHENTICATION_AKA_V2                                  2

// rscmwdau_rngSubscriberKeyGenerationAlgorithm
#define RSCMWDAU_VAL_GENERATION_ALGORITHM_XOR                               0
#define RSCMWDAU_VAL_GENERATION_ALGORITHM_MILENAGE                          1

// rscmwdau_rngSubscriberIntegrityAlgorithm
#define RSCMWDAU_VAL_INTEGRITY_MD5                                          0
#define RSCMWDAU_VAL_INTEGRITY_SHA1                                         1
#define RSCMWDAU_VAL_INTEGRITY_AUTO                                         2

// rscmwdau_rngSubscriberEncryptionAlgorithm
#define RSCMWDAU_VAL_ENCRYPTION_NONE                                        0
#define RSCMWDAU_VAL_ENCRYPTION_DES                                         1
#define RSCMWDAU_VAL_ENCRYPTION_AES                                         2
#define RSCMWDAU_VAL_ENCRYPTION_AUTO                                        3

// rscmwdau_rngVirtualSubscriberBehavior
#define RSCMWDAU_VAL_ANSWER                                                 0
#define RSCMWDAU_VAL_NO_ANSWER                                              1
#define RSCMWDAU_VAL_DECLINED                                               2
#define RSCMWDAU_VAL_BUSY                                                   3
#define RSCMWDAU_VAL_BEFRNG                                                 4
#define RSCMWDAU_VAL_AFTRNG                                                 5
#define RSCMWDAU_VAL_CD                                                     6

// rscmwdau_rngVirtualSubscriberSignalingType
#define RSCMWDAU_VAL_WITH_PRECONDITION                                      0
#define RSCMWDAU_VAL_WITHOUT_PRECONDITION                                   1
#define RSCMWDAU_VAL_SIMPLE_CALL                                            2
#define RSCMWDAU_VAL_SIMPLE_REQUIRE100                                      3
#define RSCMWDAU_VAL_SIMPLE_REQUIRE_PRECONDITION                            4
#define RSCMWDAU_VAL_SIMPLE_REQUIRE_WOTP                                    6
#define RSCMWDAU_VAL_SIMPLE_REQUIRE_EARL                                    7

// rscmwdau_rngVirtualSubscriberCodecVideo
#define RSCMWDAU_VAL_VIDEO_CODEC_H263                                       0
#define RSCMWDAU_VAL_VIDEO_CODEC_H264                                       1

// rscmwdau_rngVirtualSubscriberMediaEndpoint
#define RSCMWDAU_VAL_AUDIO_BOARD                                            0
#define RSCMWDAU_VAL_LOOP_BACK                                              1
#define RSCMWDAU_VAL_FORWARD                                                2
#define RSCMWDAU_VAL_PCAP                                                   3

// rscmwdau_rngVirtualSubscriberAMRAlignmentMode
#define RSCMWDAU_VAL_IMS_MODE_OCTET_ALIGNED                                 0
#define RSCMWDAU_VAL_IMS_MODE_BANDWIDTH                                     1

// rscmwdau_rngVirtualSubscriberMTCCallType
#define RSCMWDAU_VAL_CALL_TYPE_AUDIO                                        0
#define RSCMWDAU_VAL_CALL_TYPE_VIDEO                                        1

// rscmwdau_rngVirtualSubscriberMTCAMRAlignment
#define RSCMWDAU_VAL_IMS_VOICE_AMR_OCTET_ALIGNED                            0
#define RSCMWDAU_VAL_IMS_VOICE_AMR_BANDWIDTH_EFFICIENT                      1

// rscmwdau_rngVirtualSubscriberSMSType
#define RSCMWDAU_VAL_IMS_SMS_TYPE_ACK                                       2
#define RSCMWDAU_VAL_IMS_SMS_TYPE_PAGER                                     3
#define RSCMWDAU_VAL_IMS_SMS_TYPE_LARGE                                     4
#define RSCMWDAU_VAL_IMS_SMS_TYPE_RCSC                                      5
#define RSCMWDAU_VAL_IMS_SMS_TYPE_RCSG                                      6
#define RSCMWDAU_VAL_IMS_SMS_TYPE_GENERIC                                   7

// rscmwdau_rngePDGIDType
#define RSCMWDAU_VAL_ID_IPV4_ADDR                                           0
#define RSCMWDAU_VAL_ID_FQDN                                                1
#define RSCMWDAU_VAL_ID_RFC822_ADDR                                         2
#define RSCMWDAU_VAL_ID_IPV6_ADDR                                           3
#define RSCMWDAU_VAL_ID_KEY_ID                                              4

// rscmwdau_rngePDGIKEEncryption
#define RSCMWDAU_VAL_ENCRYPTION_AES_CBC                                     0

// rscmwdau_rngePDGIKEPRF
#define RSCMWDAU_VAL_PRF_FUNCTION_NONE                                      0
#define RSCMWDAU_VAL_PRF_FUNCTION_MD5                                       1
#define RSCMWDAU_VAL_PRF_FUNCTION_SHA1                                      2

// rscmwdau_rngePDGIKEIntegrity
#define RSCMWDAU_VAL_INTEGRITY_XCBC                                         2

// rscmwdau_rngePDGDiffieHellman
#define RSCMWDAU_VAL_DIFFIE_HELLMAN_GROUP_ONE                               0
#define RSCMWDAU_VAL_DIFFIE_HELLMAN_GROUP_TWO                               1
#define RSCMWDAU_VAL_DIFFIE_HELLMAN_GROUP_FIVE                              2
#define RSCMWDAU_VAL_DIFFIE_HELLMAN_GROUP_FORTEEN                           3
#define RSCMWDAU_VAL_DIFFIE_HELLMAN_GROUP_FIVETEEN                          4
#define RSCMWDAU_VAL_DIFFIE_HELLMAN_GROUP_SIXTEEN                           5
#define RSCMWDAU_VAL_DIFFIE_HELLMAN_GROUP_SEVENTEEN                         6
#define RSCMWDAU_VAL_DIFFIE_HELLMAN_GROUP_EIGHTEEN                          7

// rscmwdau_rngePDGAuthenticationAlgorithm
#define RSCMWDAU_VAL_ALGORITHM_XOR                                          0
#define RSCMWDAU_VAL_ALGORITHM_MILENAGE                                     1

// rscmwdau_rngePDGAuthenticationKeyType
#define RSCMWDAU_VAL_KEY_TYPE_OPC                                           0

// rscmwdau_rngPCSCFFailureCode
#define RSCMWDAU_VAL_BAD_REQUEST                                            0
#define RSCMWDAU_VAL_BAD_FORBIDDEN                                          1
#define RSCMWDAU_VAL_NOT_FOUND                                              2
#define RSCMWDAU_VAL_INTERNAL_ERROR                                         3
#define RSCMWDAU_VAL_UNAVAILABLE                                            4
#define RSCMWDAU_VAL_BUSY_EVERYWHERE                                        5

// rscmwdau_rngPCSCFBehavior
#define RSCMWDAU_VAL_BEHAVIOR_NORMAL                                        0
#define RSCMWDAU_VAL_BEHAVIOR_FAILURE                                       1

// rscmwdau_rngIPv6AddressLength
#define RSCMWDAU_VAL_IPV6_ADDRESS_LENGTH_L16                                0
#define RSCMWDAU_VAL_IPV6_ADDRESS_LENGTH_L17                                1

// rscmwdau_rngIMSTransportSelection
#define RSCMWDAU_VAL_IMS_TRANSPORT_SELECTION_DEF                            0
#define RSCMWDAU_VAL_IMS_TRANSPORT_SELECTION_TCP                            1
#define RSCMWDAU_VAL_IMS_TRANSPORT_SELECTION_UDP                            2
#define RSCMWDAU_VAL_IMS_TRANSPORT_SELECTION_CUST                           3

// rscmwdau_rngUpdateCallEvent
#define RSCMWDAU_VAL_UPDATE_CALL_EVENT_HOLD                                 0
#define RSCMWDAU_VAL_UPDATE_CALL_EVENT_RESUME                               1

// rscmwdau_rngEVSStartMode
#define RSCMWDAU_VAL_EVS_START_MODE_PRIMARY                                 0
#define RSCMWDAU_VAL_EVS_START_MODE_AMR                                     1

// rscmwdau_rngEVSHFOnly
#define RSCMWDAU_VAL_EVS_HF_ONLY_BOTH                                       0
#define RSCMWDAU_VAL_EVS_HF_ONLY_HEADER                                     1
#define RSCMWDAU_VAL_EVS_HF_ONLY_NP                                         2

// rscmwdau_rngEVSDTX
#define RSCMWDAU_VAL_EVS_DTX_DISABLE                                        0
#define RSCMWDAU_VAL_EVS_DTX_ENABLE                                         1
#define RSCMWDAU_VAL_EVS_DTX_NP                                             2

// rscmwdau_rngEVSConfigurationMode
#define RSCMWDAU_VAL_EVS_CONFIG_MODE_COMMON                                 0
#define RSCMWDAU_VAL_EVS_CONFIG_MODE_SENDRX                                 1

// rscmwdau_rngEVSBandwidthCommon
#define RSCMWDAU_VAL_EVS_BW_COMMON_NB                                       0
#define RSCMWDAU_VAL_EVS_BW_COMMON_WB                                       1
#define RSCMWDAU_VAL_EVS_BW_COMMON_SWB                                      2
#define RSCMWDAU_VAL_EVS_BW_COMMON_FB                                       3
#define RSCMWDAU_VAL_EVS_BW_COMMON_NBWB                                     4
#define RSCMWDAU_VAL_EVS_BW_COMMON_NBSW                                     5
#define RSCMWDAU_VAL_EVS_BW_COMMON_NBFB                                     6

// rscmwdau_rngEVSCMR
#define RSCMWDAU_VAL_EVS_CMR_DISABLE                                        0
#define RSCMWDAU_VAL_EVS_CMR_ENABLE                                         1
#define RSCMWDAU_VAL_EVS_CMR_PRESENT                                        2
#define RSCMWDAU_VAL_EVS_CMR_NP                                             3

// rscmwdau_rngEVSCHAW
#define RSCMWDAU_VAL_EVS_CHAW_DISABLED                                      0
#define RSCMWDAU_VAL_EVS_CHAW_NUS                                           1
#define RSCMWDAU_VAL_EVS_CHAW_TWO                                           2
#define RSCMWDAU_VAL_EVS_CHAW_THREE                                         3
#define RSCMWDAU_VAL_EVS_CHAW_FIVE                                          4
#define RSCMWDAU_VAL_EVS_CHAW_SEVEN                                         5
#define RSCMWDAU_VAL_EVS_CHAW_NP                                            6

// rscmwdau_rngFileTransferType
#define RSCMWDAU_VAL_MTF_TYPE_FILE                                          0
#define RSCMWDAU_VAL_MTF_TYPE_LARGE                                         1

// rscmwdau_rngSMSEncoding
#define RSCMWDAU_VAL_SMS_ENCODING_NONE                                      0
#define RSCMWDAU_VAL_SMS_ENCODING_BASE64                                    1

// rscmwdau_rngIPerfType
#define RSCMWDAU_VAL_IPERF_TYPE_IPERF                                       0
#define RSCMWDAU_VAL_IPERF_TYPE_IP3                                         1

// rscmwdau_rngQoSProfileProtocol
#define RSCMWDAU_VAL_QOS_PROTOCOL_ALL                                       0
#define RSCMWDAU_VAL_QOS_PROTOCOL_TCP                                       1
#define RSCMWDAU_VAL_QOS_PROTOCOL_UDP                                       2

// rscmwdau_rngQoSProfileJitterDistribution
#define RSCMWDAU_VAL_QOS_JITTER_UNIFORM                                     0
#define RSCMWDAU_VAL_QOS_JITTER_NORMAL                                      1
#define RSCMWDAU_VAL_QOS_JITTER_PARETO                                      2
#define RSCMWDAU_VAL_QOS_JITTER_PNORMAL                                     3

// rscmwdau_rngApplicationType
#define RSCMWDAU_VAL_APP_TYPE_OVER                                          0
#define RSCMWDAU_VAL_APP_TYPE_PING                                          1
#define RSCMWDAU_VAL_APP_TYPE_IPER                                          2
#define RSCMWDAU_VAL_APP_TYPE_THR                                           3
#define RSCMWDAU_VAL_APP_TYPE_DNSR                                          4
#define RSCMWDAU_VAL_APP_TYPE_IPL                                           5
#define RSCMWDAU_VAL_APP_TYPE_IPAN                                          6
#define RSCMWDAU_VAL_APP_TYPE_IPR                                           7
#define RSCMWDAU_VAL_APP_TYPE_AUD                                           8

// rscmwdau_rngThroughputType
#define RSCMWDAU_VAL_THROUGH_TYPE_OVER                                      0
#define RSCMWDAU_VAL_THROUGH_TYPE_RAN                                       1

// rscmwdau_rngVirtualAudioCodec
#define RSCMWDAU_VAL_CODEC_NARROWBAND                                       0
#define RSCMWDAU_VAL_CODEC_WIDEBAND                                         1
#define RSCMWDAU_VAL_CODEC_EVS                                              2

// rscmwdau_rngEVSBandwidth
#define RSCMWDAU_VAL_EVS_BW_NB                                              0
#define RSCMWDAU_VAL_EVS_BW_IO                                              1
#define RSCMWDAU_VAL_EVS_BW_WB                                              2
#define RSCMWDAU_VAL_EVS_BW_SWB                                             3
#define RSCMWDAU_VAL_EVS_BW_FB                                              4
#define RSCMWDAU_VAL_EVS_BW_WBCA                                            5
#define RSCMWDAU_VAL_EVS_BW_SWBCA                                           6
#define RSCMWDAU_VAL_EVS_BW_NOREQ                                           7
#define RSCMWDAU_VAL_EVS_BW_DEAC                                            8

// rscmwdau_rngCMRRepetition
#define RSCMWDAU_VAL_CMR_ENDLESS                                            0
#define RSCMWDAU_VAL_CMR_ONCE                                               1

// rscmwdau_rngEVSBitrate
#define RSCMWDAU_VAL_EVS_BITRATE_NOREQ                                      0
#define RSCMWDAU_VAL_EVS_BITRATE_PR59                                       1
#define RSCMWDAU_VAL_EVS_BITRATE_PR72                                       2
#define RSCMWDAU_VAL_EVS_BITRATE_PR80                                       3
#define RSCMWDAU_VAL_EVS_BITRATE_PR96                                       4
#define RSCMWDAU_VAL_EVS_BITRATE_P132                                       5
#define RSCMWDAU_VAL_EVS_BITRATE_P164                                       6
#define RSCMWDAU_VAL_EVS_BITRATE_P244                                       7
#define RSCMWDAU_VAL_EVS_BITRATE_P320                                       8
#define RSCMWDAU_VAL_EVS_BITRATE_P480                                       9
#define RSCMWDAU_VAL_EVS_BITRATE_P640                                       10
#define RSCMWDAU_VAL_EVS_BITRATE_P960                                       11
#define RSCMWDAU_VAL_EVS_BITRATE_P1280                                      12
#define RSCMWDAU_VAL_EVS_BITRATE_AW66                                       13
#define RSCMWDAU_VAL_EVS_BITRATE_AW885                                      14
#define RSCMWDAU_VAL_EVS_BITRATE_AW1265                                     15
#define RSCMWDAU_VAL_EVS_BITRATE_AW1425                                     16
#define RSCMWDAU_VAL_EVS_BITRATE_AW1585                                     17
#define RSCMWDAU_VAL_EVS_BITRATE_AW1825                                     18
#define RSCMWDAU_VAL_EVS_BITRATE_AW1985                                     19
#define RSCMWDAU_VAL_EVS_BITRATE_AW2305                                     20
#define RSCMWDAU_VAL_EVS_BITRATE_AWB2385                                    21
#define RSCMWDAU_VAL_EVS_BITRATE_SLO2                                       22
#define RSCMWDAU_VAL_EVS_BITRATE_SLO3                                       23
#define RSCMWDAU_VAL_EVS_BITRATE_SLO5                                       24
#define RSCMWDAU_VAL_EVS_BITRATE_SLO7                                       25
#define RSCMWDAU_VAL_EVS_BITRATE_SHO2                                       26
#define RSCMWDAU_VAL_EVS_BITRATE_SHO3                                       27
#define RSCMWDAU_VAL_EVS_BITRATE_SHO5                                       28
#define RSCMWDAU_VAL_EVS_BITRATE_SHO7                                       29
#define RSCMWDAU_VAL_EVS_BITRATE_WLO2                                       30
#define RSCMWDAU_VAL_EVS_BITRATE_WLO3                                       31
#define RSCMWDAU_VAL_EVS_BITRATE_WLO5                                       32
#define RSCMWDAU_VAL_EVS_BITRATE_WLO7                                       33
#define RSCMWDAU_VAL_EVS_BITRATE_WHO2                                       34
#define RSCMWDAU_VAL_EVS_BITRATE_WHO3                                       35
#define RSCMWDAU_VAL_EVS_BITRATE_WHO5                                       36
#define RSCMWDAU_VAL_EVS_BITRATE_WHO7                                       37

// rscmwdau_rngAMRBitrates
#define RSCMWDAU_VAL_AMR_R475                                               0
#define RSCMWDAU_VAL_AMR_R515                                               1
#define RSCMWDAU_VAL_AMR_R590                                               2
#define RSCMWDAU_VAL_AMR_R670                                               3
#define RSCMWDAU_VAL_AMR_R740                                               4
#define RSCMWDAU_VAL_AMR_R795                                               5
#define RSCMWDAU_VAL_AMR_R1020                                              6
#define RSCMWDAU_VAL_AMR_R1220                                              7
#define RSCMWDAU_VAL_AMR_NOREQ                                              8

// rscmwdau_rngAMRWBBitrates
#define RSCMWDAU_VAL_AMRWB_R660                                             0
#define RSCMWDAU_VAL_AMRWB_R885                                             1
#define RSCMWDAU_VAL_AMRWB_R1265                                            2
#define RSCMWDAU_VAL_AMRWB_R1425                                            3
#define RSCMWDAU_VAL_AMRWB_R1585                                            4
#define RSCMWDAU_VAL_AMRWB_R1825                                            5
#define RSCMWDAU_VAL_AMRWB_R1985                                            6
#define RSCMWDAU_VAL_AMRWB_R2305                                            7
#define RSCMWDAU_VAL_AMRWB_RA2385                                           8
#define RSCMWDAU_VAL_AMRWB_NOREQ                                            9

// rscmwdau_rngePDGState
#define RSCMWDAU_VAL_EPDG_OFF                                               0
#define RSCMWDAU_VAL_EPDG_ON                                                1
#define RSCMWDAU_VAL_EPDG_PENDING                                           2
#define RSCMWDAU_VAL_EPDG_ADJUSTED                                          3
#define RSCMWDAU_VAL_EPDG_AUTONOMOUS                                        4
#define RSCMWDAU_VAL_EPDG_COUPLED                                           5
#define RSCMWDAU_VAL_EPDG_INVALID                                           6

// rscmwdau_rngLANStatus
#define RSCMWDAU_VAL_LAN_STATUS_NOTC                                        0
#define RSCMWDAU_VAL_LAN_STATUS_CONN                                        1

// rscmwdau_rngSubscriberPAUHeader
#define RSCMWDAU_VAL_PAU_HEADER_CONR                                        0
#define RSCMWDAU_VAL_PAU_HEADER_REC                                         1
#define RSCMWDAU_VAL_PAU_HEADER_CORE                                        2
#define RSCMWDAU_VAL_PAU_HEADER_RECN                                        3
#define RSCMWDAU_VAL_PAU_HEADER_COGE                                        4
#define RSCMWDAU_VAL_PAU_HEADER_REGE                                        5
#define RSCMWDAU_VAL_PAU_HEADER_CONF                                        6
#define RSCMWDAU_VAL_PAU_HEADER_REGD                                        7

// rscmwdau_rngEVSIOModeConfig
#define RSCMWDAU_VAL_EVS_IO_MODE_CONFIG_EVS                                 0
#define RSCMWDAU_VAL_EVS_IO_MODE_CONFIG_AMRW                                1

// rscmwdau_rngFilterConnections
#define RSCMWDAU_VAL_FILTER_CONNECTIONS_CLOSED                              0
#define RSCMWDAU_VAL_FILTER_CONNECTIONS_OPEN                                1
#define RSCMWDAU_VAL_FILTER_CONNECTIONS_BOTH                                2

// rscmwdau_rngLayer4Protocol
#define RSCMWDAU_VAL_LAYER_4_PROTOCOL_TCP                                   0
#define RSCMWDAU_VAL_LAYER_4_PROTOCOL_UDP                                   1

// rscmwdau_rngSIPTimerSelection
#define RSCMWDAU_IMS_SIP_TIMER_SELECTION_DEFAULT                            0
#define RSCMWDAU_IMS_SIP_TIMER_SELECTION_RFC                                1
#define RSCMWDAU_IMS_SIP_TIMER_SELECTION_CUSTOM                             2

//repcap instance
#define RSCMWDAU_REPCAP_INSTANCE_I1                                         1
#define RSCMWDAU_REPCAP_INSTANCE_I2                                         2
#define RSCMWDAU_REPCAP_INSTANCE_I3                                         3
#define RSCMWDAU_REPCAP_INSTANCE_I4                                         4
#define RSCMWDAU_REPCAP_INSTANCE_I5                                         5
#define RSCMWDAU_REPCAP_INSTANCE_I6                                         6
#define RSCMWDAU_REPCAP_INSTANCE_I7                                         7
#define RSCMWDAU_REPCAP_INSTANCE_I8                                         8
#define RSCMWDAU_REPCAP_INSTANCE_I9                                         9
#define RSCMWDAU_REPCAP_INSTANCE_I10                                        10
#define RSCMWDAU_REPCAP_INSTANCE_I11                                        11
#define RSCMWDAU_REPCAP_INSTANCE_I12                                        12
#define RSCMWDAU_REPCAP_INSTANCE_I13                                        13
#define RSCMWDAU_REPCAP_INSTANCE_I14                                        14
#define RSCMWDAU_REPCAP_INSTANCE_I15                                        15
#define RSCMWDAU_REPCAP_INSTANCE_I16                                        16

//repcap DNSType
#define RSCMWDAU_REPCAP_DNSTYPE_PRIMARY                                     0
#define RSCMWDAU_REPCAP_DNSTYPE_SECONDARY                                   1

//repcap service
#define RSCMWDAU_REPCAP_SERVICE_FTP                                         0
#define RSCMWDAU_REPCAP_SERVICE_HTTP                                        1
#define RSCMWDAU_REPCAP_SERVICE_DNS                                         2
#define RSCMWDAU_REPCAP_SERVICE_IMS                                         3

//repcap clientServer
#define RSCMWDAU_REPCAP_CLIENTSERVER_CLIENT                                 0
#define RSCMWDAU_REPCAP_CLIENTSERVER_SERVER                                 1
#define RSCMWDAU_REPCAP_CLIENTSERVER_NAT                                    2

//repcap IPerfInstance
#define RSCMWDAU_REPCAP_IPERFINSTANCE_IPERF1                                1
#define RSCMWDAU_REPCAP_IPERFINSTANCE_IPERF2                                2
#define RSCMWDAU_REPCAP_IPERFINSTANCE_IPERF3                                3
#define RSCMWDAU_REPCAP_IPERFINSTANCE_IPERF4                                4
#define RSCMWDAU_REPCAP_IPERFINSTANCE_IPERF5                                5
#define RSCMWDAU_REPCAP_IPERFINSTANCE_IPERF6                                6
#define RSCMWDAU_REPCAP_IPERFINSTANCE_IPERF7                                7
#define RSCMWDAU_REPCAP_IPERFINSTANCE_IPERF8                                8

//repcap measurement
#define RSCMWDAU_REPCAP_MEASUREMENT_PING                                    0
#define RSCMWDAU_REPCAP_MEASUREMENT_IPERF                                   1
#define RSCMWDAU_REPCAP_MEASUREMENT_THROUGHPUT                              2
#define RSCMWDAU_REPCAP_MEASUREMENT_DNSREQUESTS                             3
#define RSCMWDAU_REPCAP_MEASUREMENT_IPLOGGING                               4
#define RSCMWDAU_REPCAP_MEASUREMENT_IPANALYSIS                              5
#define RSCMWDAU_REPCAP_MEASUREMENT_IPREPLAY                                6

//repcap DNSServer
#define RSCMWDAU_REPCAP_DNSSERVER_DNSPRIMARY                                0
#define RSCMWDAU_REPCAP_DNSSERVER_DNSSECONDARY                              1

//repcap IPVersion
#define RSCMWDAU_REPCAP_IPVERSION_IPV4                                      0
#define RSCMWDAU_REPCAP_IPVERSION_IPV6                                      1

//repcap CodecIdx
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX0                                  1
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX1                                  2
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX2                                  3
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX3                                  4
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX4                                  5
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX5                                  6
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX6                                  7
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX7                                  8
#define RSCMWDAU_REPCAP_CODECIDX_CODECINX8                                  9

//repcap Index
#define RSCMWDAU_REPCAP_INDEX_IMP1                                          1
#define RSCMWDAU_REPCAP_INDEX_IMP2                                          2
#define RSCMWDAU_REPCAP_INDEX_IMP3                                          3
#define RSCMWDAU_REPCAP_INDEX_IMP4                                          4
#define RSCMWDAU_REPCAP_INDEX_IMP5                                          5
#define RSCMWDAU_REPCAP_INDEX_IMP6                                          6
#define RSCMWDAU_REPCAP_INDEX_IMP7                                          7

//repcap TraceIndex
#define RSCMWDAU_REPCAP_TRACEINDEX_TI1                                      1
#define RSCMWDAU_REPCAP_TRACEINDEX_TI2                                      2
#define RSCMWDAU_REPCAP_TRACEINDEX_TI3                                      3
#define RSCMWDAU_REPCAP_TRACEINDEX_TI4                                      4
#define RSCMWDAU_REPCAP_TRACEINDEX_TI5                                      5
#define RSCMWDAU_REPCAP_TRACEINDEX_TI6                                      6
#define RSCMWDAU_REPCAP_TRACEINDEX_TI7                                      7
#define RSCMWDAU_REPCAP_TRACEINDEX_TI8                                      8
#define RSCMWDAU_REPCAP_TRACEINDEX_TI9                                      9
#define RSCMWDAU_REPCAP_TRACEINDEX_TI10                                     10

//repcap IMS
#define RSCMWDAU_REPCAP_IMS_IMS1                                            1
#define RSCMWDAU_REPCAP_IMS_IMS2                                            2

//repcap Profile
#define RSCMWDAU_REPCAP_PROFILE_P1                                          1
#define RSCMWDAU_REPCAP_PROFILE_P2                                          2
#define RSCMWDAU_REPCAP_PROFILE_P3                                          3
#define RSCMWDAU_REPCAP_PROFILE_P4                                          4
#define RSCMWDAU_REPCAP_PROFILE_P5                                          5
#define RSCMWDAU_REPCAP_PROFILE_P6                                          6
#define RSCMWDAU_REPCAP_PROFILE_P7                                          7
#define RSCMWDAU_REPCAP_PROFILE_P8                                          8
#define RSCMWDAU_REPCAP_PROFILE_P9                                          9
#define RSCMWDAU_REPCAP_PROFILE_P10                                         10

//repcap Subscriber
#define RSCMWDAU_REPCAP_SUBSCRIBER_S1                                       1
#define RSCMWDAU_REPCAP_SUBSCRIBER_S2                                       2
#define RSCMWDAU_REPCAP_SUBSCRIBER_S3                                       3
#define RSCMWDAU_REPCAP_SUBSCRIBER_S4                                       4
#define RSCMWDAU_REPCAP_SUBSCRIBER_S5                                       5

//repcap UserIndex
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX1                                  1
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX2                                  2
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX3                                  3
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX4                                  4
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX5                                  5
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX6                                  6
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX7                                  7
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX8                                  8
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX9                                  9
#define RSCMWDAU_REPCAP_USERINDEX_USERIDX10                                 10

//repcap VirtualSubscriber
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS1                               1
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS2                               2
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS3                               3
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS4                               4
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS5                               5
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS6                               6
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS7                               7
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS8                               8
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS9                               9
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS10                              10
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS11                              11
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS12                              12
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS13                              13
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS14                              14
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS15                              15
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS16                              16
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS17                              17
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS18                              18
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS19                              19
#define RSCMWDAU_REPCAP_VIRTUALSUBSCRIBER_VS20                              20

//repcap UserEquipment
#define RSCMWDAU_REPCAP_USEREQUIPMENT_UE1                                   1
#define RSCMWDAU_REPCAP_USEREQUIPMENT_UE2                                   2
#define RSCMWDAU_REPCAP_USEREQUIPMENT_UE3                                   3
#define RSCMWDAU_REPCAP_USEREQUIPMENT_UE4                                   4
#define RSCMWDAU_REPCAP_USEREQUIPMENT_UE5                                   5

//repcap QoS
#define RSCMWDAU_REPCAP_QOS_QOS1                                            1
#define RSCMWDAU_REPCAP_QOS_QOS2                                            2
#define RSCMWDAU_REPCAP_QOS_QOS3                                            3
#define RSCMWDAU_REPCAP_QOS_QOS4                                            4
#define RSCMWDAU_REPCAP_QOS_QOS5                                            5
#define RSCMWDAU_REPCAP_QOS_QOS6                                            6
#define RSCMWDAU_REPCAP_QOS_QOS7                                            7
#define RSCMWDAU_REPCAP_QOS_QOS8                                            8
#define RSCMWDAU_REPCAP_QOS_QOS9                                            9
#define RSCMWDAU_REPCAP_QOS_QOS10                                           10
#define RSCMWDAU_REPCAP_QOS_QOS11                                           11
#define RSCMWDAU_REPCAP_QOS_QOS12                                           12
#define RSCMWDAU_REPCAP_QOS_QOS13                                           13
#define RSCMWDAU_REPCAP_QOS_QOS14                                           14
#define RSCMWDAU_REPCAP_QOS_QOS15                                           15

//repcap RAN
#define RSCMWDAU_REPCAP_RAN_RAN1                                            1
#define RSCMWDAU_REPCAP_RAN_RAN2                                            2
#define RSCMWDAU_REPCAP_RAN_RAN3                                            3
#define RSCMWDAU_REPCAP_RAN_RAN4                                            4
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWDAU_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWDAU_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWDAU_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWDAU_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/

    /*- Instrument specific attribute value definitions --------------------*/
#define RSCMWDAU_VAL_SERVICE_FTP    0
#define RSCMWDAU_VAL_SERVICE_HTTP   1
#define RSCMWDAU_VAL_SERVICE_DNS    2
#define RSCMWDAU_VAL_SERVICE_IMS    3

#define RSCMWDAU_VAL_IPERF_CLIENT   0
#define RSCMWDAU_VAL_IPERF_SERVER   1
#define RSCMWDAU_VAL_IPERF_NAT      2

#define RSCMWDAU_VAL_MEAS_PING          0
#define RSCMWDAU_VAL_MEAS_IPERF         1
#define RSCMWDAU_VAL_MEAS_THROUGHPUT    2
#define RSCMWDAU_VAL_MEAS_DNS_REQUESTS  3
#define RSCMWDAU_VAL_MEAS_IP_LOGGING    4
#define RSCMWDAU_VAL_MEAS_IP_ANALYSIS   5
#define RSCMWDAU_VAL_MEAS_IP_REPLAY     6

#define RSCMWDAU_VAL_THROUGHPUT_UPLINK      0
#define RSCMWDAU_VAL_THROUGHPUT_DOWNLINK    1

#define RSCMWDAU_VAL_RESULT_CURRENT 0

#define RSCMWDAU_VAL_IPV6_PREFIX_AUTO 2

#define RSCMWDAU_VAL_PRIMARY   0
#define RSCMWDAU_VAL_SECONDARY 1

#define RSCMWDAU_VAL_IMS_VOICE_CALL_ESTABLISH  0
#define RSCMWDAU_VAL_IMS_VOICE_CALL_DISCONNECT 1

#define RSCMWDAU_VAL_UDP 0
#define RSCMWDAU_VAL_TCP 1

#define RSCMWDAU_VAL_NETWORK_IMPAIRMENT_DOWN 0

#define RSCMWDAU_VAL_RES_TCP_ANALYSIS 0
#define RSCMWDAU_VAL_RES_IP_CONNECT   1
#define RSCMWDAU_VAL_RES_DPCP         2
#define RSCMWDAU_VAL_RES_FT_TRIGGER   3
#define RSCMWDAU_VAL_RES_IMS          4

#define RSCMWDAU_VAL_TRESHOLD_TPC_WINDOW          0
#define RSCMWDAU_VAL_TRESHOLD_TPC_RETRANSMISSIONS 1
#define RSCMWDAU_VAL_TRESHOLD_TPC_OVERHEAD        2
#define RSCMWDAU_VAL_TRESHOLD_TPC_RTT             3

#define RSCMWDAU_VAL_NETWORK_INTERFACE_LAND 0
#define RSCMWDAU_VAL_NETWORK_INTERFACE_IP   1
#define RSCMWDAU_VAL_NETWORK_INTERFACE_MULT 2

#define RSCMWDAU_VAL_DIRECTION_UL  0
#define RSCMWDAU_VAL_DIRECTION_DL  1
#define RSCMWDAU_VAL_DIRECTION_UNK 2

#define RSCMWDAU_VAL_FLOW_TYPE_AUDIO 0
#define RSCMWDAU_VAL_FLOW_TYPE_VIDEO 1
#define RSCMWDAU_VAL_FLOW_TYPE_UNKN  2

#define RSCMWDAU_VAL_FORCE_MODE_NB_ZERO  0
#define RSCMWDAU_VAL_FORCE_MODE_NB_ONE    1
#define RSCMWDAU_VAL_FORCE_MODE_NB_TWO    2
#define RSCMWDAU_VAL_FORCE_MODE_NB_THREE  3
#define RSCMWDAU_VAL_FORCE_MODE_NB_FOUR   4
#define RSCMWDAU_VAL_FORCE_MODE_NB_FIVE   5
#define RSCMWDAU_VAL_FORCE_MODE_NB_SIX    6
#define RSCMWDAU_VAL_FORCE_MODE_NB_SEVEN  7
#define RSCMWDAU_VAL_FORCE_MODE_NB_FREE   8

#define RSCMWDAU_VAL_FORCE_MODE_WB_ZERO  0
#define RSCMWDAU_VAL_FORCE_MODE_WB_ONE    1
#define RSCMWDAU_VAL_FORCE_MODE_WB_TWO    2
#define RSCMWDAU_VAL_FORCE_MODE_WB_THREE  3
#define RSCMWDAU_VAL_FORCE_MODE_WB_FOUR   4
#define RSCMWDAU_VAL_FORCE_MODE_WB_FIVE   5
#define RSCMWDAU_VAL_FORCE_MODE_WB_SIX    6
#define RSCMWDAU_VAL_FORCE_MODE_WB_SEVEN  7
#define RSCMWDAU_VAL_FORCE_MODE_WB_EIGH   8
#define RSCMWDAU_VAL_FORCE_MODE_WB_FREE   9

#define RSCMWDAU_VAL_UPLINK   0
#define RSCMWDAU_VAL_DOWNLINK 1
#define RSCMWDAU_VAL_LOOPBACK 2

#define RSCMWDAU_VAL_TIME_UPLINK    0
#define RSCMWDAU_VAL_TIME_LOOPBACK  1

#define RSCMWDAU_VAL_INSTANCE_1     1

#define RSCMW_VAL_EVS_BITRATE_R59   0
#define RSCMW_VAL_EVS_BITRATE_R72   1
#define RSCMW_VAL_EVS_BITRATE_R80   2
#define RSCMW_VAL_EVS_BITRATE_R96   3
#define RSCMW_VAL_EVS_BITRATE_R132  4
#define RSCMW_VAL_EVS_BITRATE_R164  5
#define RSCMW_VAL_EVS_BITRATE_R244  6
#define RSCMW_VAL_EVS_BITRATE_R320  7
#define RSCMW_VAL_EVS_BITRATE_R480  8
#define RSCMW_VAL_EVS_BITRATE_R640  9
#define RSCMW_VAL_EVS_BITRATE_R960  10
#define RSCMW_VAL_EVS_BITRATE_R1280 11

#define RSCMWDAU_VAL_EVS_BW_SELECT_COMMON  0
#define RSCMWDAU_VAL_EVS_BW_SELECT_SEND    1
#define RSCMWDAU_VAL_EVS_BW_SELECT_RECEIVE 2

#define RSCMWDAU_VAL_IP_ANALYSIS_FILTER_TYPE_FLOW 0
#define RSCMWDAU_VAL_IP_ANALYSIS_FILTER_TYPE_IPAD 1
#define RSCMWDAU_VAL_IP_ANALYSIS_FILTER_TYPE_L4PR 2
#define RSCMWDAU_VAL_IP_ANALYSIS_FILTER_TYPE_L7PR 3

#define RSCMWDAU_VAL_FLOW_FILTER_TYPE_FLOWID  0
#define RSCMWDAU_VAL_FLOW_FILTER_TYPE_IPADD   1
#define RSCMWDAU_VAL_FLOW_FILTER_TYPE_L4PR    2
#define RSCMWDAU_VAL_FLOW_FILTER_TYPE_L7PR    3
#define RSCMWDAU_VAL_FLOW_FILTER_TYPE_APPL    4
#define RSCMWDAU_VAL_FLOW_FILTER_TYPE_COUNTRY 5
#define RSCMWDAU_VAL_FLOW_FILTER_TYPE_SRCPORT 6
#define RSCMWDAU_VAL_FLOW_FILTER_TYPE_DSTPORT 7

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rscmwdau_init(ViRsrc     resourceName,
                                ViBoolean  IDQuery,
                                ViBoolean  resetDevice,
                                ViSession* instrumentHandle);

ViStatus _VI_FUNC rscmwdau_InitWithOptions(ViRsrc     resourceName,
                                           ViBoolean  IDQuery,
                                           ViBoolean  resetDevice,
                                           ViString   optionString,
                                           ViSession* instrumentHandle);

ViStatus _VI_FUNC rscmwdau_ConfigureDAUState(ViSession instrumentHandle,
                                             ViInt32   timeout,
                                             ViBoolean DAUState);

ViStatus _VI_FUNC rscmwdau_ConfigureServiceState(ViSession instrumentHandle,
                                                 ViInt32   service,
                                                 ViBoolean serviceState);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSServiceState(ViSession instrumentHandle,
                                                    ViInt32   IMS,
                                                    ViBoolean serviceState);

ViStatus _VI_FUNC rscmwdau_ConfigureMTU(ViSession instrumentHandle,
                                        ViInt32   maximumTransmissionUnit);

ViStatus _VI_FUNC rscmwdau_QueryLANStatus(ViSession instrumentHandle,
                                          ViInt32*  LANStatus);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv4AddressSetupMode(ViSession instrumentHandle,
                                                         ViInt32   mode);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv4IPAddress(ViSession instrumentHandle,
                                                  ViString  address,
                                                  ViString  subnetMask);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv4GatewayAddress(ViSession instrumentHandle,
                                                       ViString  gatewayIP);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv4AddressAdd(ViSession instrumentHandle,
                                                   ViString  address);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv4AddressDelete(ViSession instrumentHandle,
                                                      ViString  address);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv4Type(ViSession instrumentHandle,
                                             ViInt32   type);

ViStatus _VI_FUNC rscmwdau_QueryIPv4AddressesCatalog(ViSession instrumentHandle,
                                                     ViInt32   mode,
                                                     ViInt32   bufferSize,
                                                     ViChar    _VI_FAR addresesList[],
                                                     ViInt32*  numberOfAddresses);

ViStatus _VI_FUNC rscmwdau_QueryIPv4NetworkSettings(ViSession instrumentHandle,
                                                    ViInt32   bufferSize,
                                                    ViChar    _VI_FAR address[],
                                                    ViChar    _VI_FAR subnetMask[],
                                                    ViChar    _VI_FAR gatewayIP[]);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6AddressSetupMode(ViSession instrumentHandle,
                                                         ViInt32   mode);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6LANStaticConfiguration(
                            ViSession instrumentHandle,
                            ViString  IPv6Address,
                            ViString  defaultRouter);

ViStatus _VI_FUNC rscmwdau_QueryIPv6LANSettings(ViSession instrumentHandle,
                                                ViInt32   bufferSize,
                                                ViChar    _VI_FAR IPv6Address[],
                                                ViChar    _VI_FAR defaultRouter[]);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6PrefixSetupMode(ViSession instrumentHandle,
                                                        ViInt32   type);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6PrefixPoolEnabled(ViSession instrumentHandle,
                                                          ViBoolean prefixPool);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6PrefixAdd(ViSession instrumentHandle,
                                                  ViString  prefix);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6PrefixDelete(ViSession instrumentHandle,
                                                     ViString  prefix);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6PrefixDeleteByIndex(ViSession instrumentHandle,
                                                            ViInt32   index);

ViStatus _VI_FUNC rscmwdau_QueryIPv6PrefixesCatalog(ViSession instrumentHandle,
                                                    ViInt32   type,
                                                    ViInt32   bufferSize,
                                                    ViChar    _VI_FAR addresesList[],
                                                    ViInt32*  numberOfAddresses);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6RoutingSetupMode(ViSession instrumentHandle,
                                                         ViInt32   type);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6RoutingAdd(ViSession instrumentHandle,
                                                   ViString  prefix,
                                                   ViString  router);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6RoutingDelete(ViSession instrumentHandle,
                                                      ViString  prefix);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6RoutingDeleteByIndex(ViSession instrumentHandle,
                                                             ViInt32   index);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6Type(ViSession instrumentHandle,
                                             ViInt32   type);

ViStatus _VI_FUNC rscmwdau_ConfigureIPv6AddressLength(ViSession instrumentHandle,
                                                      ViInt32   addressLength);

ViStatus _VI_FUNC rscmwdau_QueryIPv6RoutingCatalog(ViSession instrumentHandle,
                                                   ViInt32   arraySize,
                                                   ViInt32   bufferSize,
                                                   ViChar    _VI_FAR prefixesList[],
                                                   ViChar    _VI_FAR routersList[],
                                                   ViInt32*  numberOfEntries);

ViStatus _VI_FUNC rscmwdau_ConfigureDNSType(ViSession instrumentHandle,
                                            ViInt32   DNSServer,
                                            ViInt32   type);

ViStatus _VI_FUNC rscmwdau_QueryDNSServerSettings(ViSession instrumentHandle,
                                                  ViInt32   DNSServer,
                                                  ViInt32   bufferSize,
                                                  ViChar    _VI_FAR IPv4Address[],
                                                  ViChar    _VI_FAR IPv6Address[]);

ViStatus _VI_FUNC rscmwdau_ConfigureForeignDNSServer(ViSession instrumentHandle,
                                                     ViInt32   DNSServer,
                                                     ViString  IPv4Address,
                                                     ViString  IPv6Address);

ViStatus _VI_FUNC rscmwdau_ConfigureForeignDNSServerUseDHCPAddress(
                            ViSession instrumentHandle,
                            ViBoolean primaryV4,
                            ViBoolean primaryV6,
                            ViBoolean secondaryV4,
                            ViBoolean secondaryV6);

ViStatus _VI_FUNC rscmwdau_AddDNSEntry(ViSession instrumentHandle,
                                       ViString  domain,
                                       ViString  IP);

ViStatus _VI_FUNC rscmwdau_DeleteDNSEntry(ViSession instrumentHandle,
                                          ViString  domainOrIP);

ViStatus _VI_FUNC rscmwdau_QueryDNSEntriesCatalog(ViSession instrumentHandle,
                                                  ViInt32   arraySize,
                                                  ViInt32   bufferSize,
                                                  ViChar    _VI_FAR domainsList[],
                                                  ViChar    _VI_FAR IPsList[],
                                                  ViInt32*  numberOfEntries);

ViStatus _VI_FUNC rscmwdau_AddApplicationEntry(ViSession instrumentHandle,
                                               ViString  name,
                                               ViString  domain,
                                               ViInt32   protocol,
                                               ViInt32   port);

ViStatus _VI_FUNC rscmwdau_DeleteApplicationEntry(ViSession instrumentHandle,
                                                  ViString  name);

ViStatus _VI_FUNC rscmwdau_QueryApplicationEntriesCatalog(ViSession instrumentHandle,
                                                          ViInt32   arraySize,
                                                          ViInt32   bufferSize,
                                                          ViChar    _VI_FAR namesList[],
                                                          ViChar    _VI_FAR domainsList[],
                                                          ViInt32   _VI_FAR protocolsList[],
                                                          ViInt32   _VI_FAR portsList[],
                                                          ViInt32*  numberOfEntries);

ViStatus _VI_FUNC rscmwdau_ConfigureForeignDNSServerDomainTest(
                            ViSession instrumentHandle,
                            ViString  domain);

ViStatus _VI_FUNC rscmwdau_StartForeignDNSServerDomainTest(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_QueryForeignDNSServerDomainTestResults(
                            ViSession instrumentHandle,
                            ViInt32*  v4ServerAvailable,
                            ViInt32*  v4AResourceRecord,
                            ViInt32*  v4AAAAResourceRecord,
                            ViInt32*  v6ServerAvailable,
                            ViInt32*  v6AResourceRecord,
                            ViInt32*  v6AAAAResourceRecord);

ViStatus _VI_FUNC rscmwdau_ConfigureDNSServerResponse(ViSession instrumentHandle,
                                                      ViBoolean response);

ViStatus _VI_FUNC rscmwdau_ConfigureFTPServiceType(ViSession instrumentHandle,
                                                   ViInt32   FTPServiceType);

ViStatus _VI_FUNC rscmwdau_ConfigureFTPServerSettings(ViSession instrumentHandle,
                                                      ViBoolean externalConnection,
                                                      ViBoolean IPv6Support,
                                                      ViBoolean anonymousUsers,
                                                      ViBoolean dataUpload);

ViStatus _VI_FUNC rscmwdau_ConfigureFTPUserAdd(ViSession instrumentHandle,
                                               ViString  userName,
                                               ViString  password,
                                               ViBoolean del,
                                               ViBoolean download,
                                               ViBoolean upload);

ViStatus _VI_FUNC rscmwdau_ConfigureFTPUserDelete(ViSession instrumentHandle,
                                                  ViString  userName,
                                                  ViString  password);

ViStatus _VI_FUNC rscmwdau_QueryFTPUsersCatalog(ViSession instrumentHandle,
                                                ViInt32   arraySize,
                                                ViInt32   bufferSize,
                                                ViChar    _VI_FAR userName[],
                                                ViBoolean _VI_FAR del[],
                                                ViBoolean _VI_FAR download[],
                                                ViBoolean _VI_FAR upload[],
                                                ViInt32*  numberOfUsers);

ViStatus _VI_FUNC rscmwdau_ConfigureHTTPServerSettings(ViSession instrumentHandle,
                                                       ViBoolean externalConnection,
                                                       ViBoolean IPv6Support);

ViStatus _VI_FUNC rscmwdau_QueryIMSStatus(ViSession instrumentHandle,
                                          ViInt32*  IMSServerStatus);

ViStatus _VI_FUNC rscmwdau_QueryIMSInfo(ViSession instrumentHandle,
                                        ViInt32   arraySize,
                                        ViInt32   bufferSize,
                                        ViChar    _VI_FAR timestamp[],
                                        ViInt32   _VI_FAR infoType[],
                                        ViChar    _VI_FAR genericInfo[],
                                        ViInt32*  numberOfEntries);

ViStatus _VI_FUNC rscmwdau_QueryAdvancedIMSInfo(ViSession instrumentHandle,
                                                ViInt32   IMS,
                                                ViInt32   arraySize,
                                                ViInt32   bufferSize,
                                                ViChar    _VI_FAR timestamp[],
                                                ViInt32   _VI_FAR infoType[],
                                                ViChar    _VI_FAR genericInfo[],
                                                ViInt32*  numberOfEntries);

ViStatus _VI_FUNC rscmwdau_QueryIMSMobileInfo(ViSession instrumentHandle,
                                              ViInt32   bufferSize,
                                              ViInt32*  mobileStatus,
                                              ViChar    _VI_FAR IPAddress[],
                                              ViChar    _VI_FAR publicUserID[],
                                              ViChar    _VI_FAR privateUserID[],
                                              ViChar    _VI_FAR homeDomain[]);

ViStatus _VI_FUNC rscmwdau_QueryIMSMobileStatus(ViSession instrumentHandle,
                                                ViInt32   IMS,
                                                ViInt32   userEquipment,
                                                ViInt32*  mobileStatus);

ViStatus _VI_FUNC rscmwdau_QueryIMSPCSCFAddress(ViSession instrumentHandle,
                                                ViInt32   bufferSize,
                                                ViChar    _VI_FAR pCSCFAddress[]);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSGeneralParameters(ViSession instrumentHandle,
                                                         ViInt32   serverUsage,
                                                         ViInt32   addressType,
                                                         ViString  pCSCFIPAddress);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSAdvancedParameters(ViSession instrumentHandle,
                                                          ViInt32   IMS,
                                                          ViInt32   serverUsage,
                                                          ViInt32   addressType,
                                                          ViString  pCSCFIPAddress);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSAuthentication(ViSession instrumentHandle,
                                                      ViBoolean useAuthentication,
                                                      ViString  privateUserID,
                                                      ViInt32   authenticationAlgorithm);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSAuthenticationData(ViSession instrumentHandle,
                                                          ViString  key,
                                                          ViString  RAND,
                                                          ViString  AMF,
                                                          ViInt32   AKAVersion,
                                                          ViInt32   RESLength);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSAuthenticationKeyType(ViSession instrumentHandle,
                                                             ViInt32   keyType,
                                                             ViString  authenticationOPcOP);

ViStatus _VI_FUNC rscmwdau_QueryIMSReleaseCall(ViSession instrumentHandle,
                                               ViInt32   IMS,
                                               ViInt32   bufferSize,
                                               ViChar    _VI_FAR callIDs[]);

ViStatus _VI_FUNC rscmwdau_DeregisterIMSMobile(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_DeregisterAdvancedIMSMobile(ViSession instrumentHandle,
                                                       ViInt32   IMS,
                                                       ViInt32   userEquipment);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSIPSec(ViSession instrumentHandle,
                                             ViBoolean IPSec,
                                             ViInt32   integrityAlgorithm,
                                             ViInt32   encryptionAlgorithm);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSVoiceSettings(ViSession instrumentHandle,
                                                     ViInt32   preconditions,
                                                     ViInt32   audioRouting,
                                                     ViString  mediaEndpointIPAddress,
                                                     ViInt32   mediaEndpointPort);

ViStatus _VI_FUNC rscmwdau_ConfigureVoiceOverIMS(ViSession instrumentHandle,
                                                 ViInt32   callType,
                                                 ViInt32   AMRType,
                                                 ViInt32   codecMode,
                                                 ViBoolean useCodec,
                                                 ViInt32   videoCodec);

ViStatus _VI_FUNC rscmwdau_VoiceOverIMSCall(ViSession instrumentHandle,
                                            ViInt32   call);

ViStatus _VI_FUNC rscmwdau_QueryVoiceOverIMSStatus(ViSession instrumentHandle,
                                                   ViInt32*  status);

ViStatus _VI_FUNC rscmwdau_QueryIMSMobileOriginatedSMS(ViSession instrumentHandle,
                                                       ViInt32   bufferSize,
                                                       ViInt32*  SMSType,
                                                       ViChar    _VI_FAR SMSText[]);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSMobileTerminatedSMS(ViSession instrumentHandle,
                                                           ViInt32   SMSType,
                                                           ViString  SMSText);

ViStatus _VI_FUNC rscmwdau_SendIMSMobileTerminatedSMS(ViSession instrumentHandle,
                                                      ViString  SMSText,
                                                      ViInt32   SMSType);

ViStatus _VI_FUNC rscmwdau_QueryIMSMobileTerminatedSMSStatus(ViSession instrumentHandle,
                                                             ViInt32*  status);

ViStatus _VI_FUNC rscmwdau_IMSCleanGeneralInfo(ViSession instrumentHandle,
                                               ViInt32   IMS);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSTCPKeepAlive(ViSession instrumentHandle,
                                                    ViInt32   IMS,
                                                    ViBoolean TCPKeepAlive);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSSIPTimerSettings(ViSession instrumentHandle,
                                                        ViInt32   timerSelection,
                                                        ViReal64  timer);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSThreshold(ViSession instrumentHandle,
                                                 ViInt32   IMS,
                                                 ViInt32   threshold);

ViStatus _VI_FUNC rscmwdau_ConfigureIMSTransportSelection(ViSession instrumentHandle,
                                                          ViInt32   IMS,
                                                          ViInt32   transportSelection);

ViStatus _VI_FUNC rscmwdau_CreatePCSCFTab(ViSession instrumentHandle,
                                          ViInt32   IMS);

ViStatus _VI_FUNC rscmwdau_DeletePCSCFTab(ViSession instrumentHandle,
                                          ViInt32   IMS,
                                          ViInt32   profileNumber);

ViStatus _VI_FUNC rscmwdau_UpdatePCSCFProfiles(ViSession instrumentHandle,
                                               ViInt32   IMS);

ViStatus _VI_FUNC rscmwdau_QueryPCSCFCatalog(ViSession instrumentHandle,
                                             ViInt32   IMS,
                                             ViInt32   bufferSize,
                                             ViChar    _VI_FAR catalog[]);

ViStatus _VI_FUNC rscmwdau_ConfigurePCSCFSettings(ViSession instrumentHandle,
                                                  ViInt32   IMS,
                                                  ViInt32   profileNumber,
                                                  ViString  IPAddress,
                                                  ViInt32   behavior);

ViStatus _VI_FUNC rscmwdau_ConfigurePCSCFFailureSettings(ViSession instrumentHandle,
                                                         ViInt32   IMS,
                                                         ViInt32   profileNumber,
                                                         ViInt32   failureCode,
                                                         ViInt32   retryAfter);

ViStatus _VI_FUNC rscmwdau_ConfigurePCSCFRegistrationExpirationTime(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   profileNumber,
                            ViInt32   minimum,
                            ViInt32   defaultTime,
                            ViInt32   maximum);

ViStatus _VI_FUNC rscmwdau_ConfigurePCSCFSubscriptionExpirationTime(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   profileNumber,
                            ViInt32   minimum,
                            ViInt32   defaultTime,
                            ViInt32   maximum);

ViStatus _VI_FUNC rscmwdau_CreateSubscriberTab(ViSession instrumentHandle,
                                               ViInt32   IMS);

ViStatus _VI_FUNC rscmwdau_DeleteSubscriberTab(ViSession instrumentHandle,
                                               ViInt32   IMS,
                                               ViInt32   subscriber);

ViStatus _VI_FUNC rscmwdau_UpdateSubscriberProfiles(ViSession instrumentHandle,
                                                    ViInt32   IMS);

ViStatus _VI_FUNC rscmwdau_QuerySubscriberCatalog(ViSession instrumentHandle,
                                                  ViInt32   IMS,
                                                  ViInt32   bufferSize,
                                                  ViChar    _VI_FAR catalog[]);

ViStatus _VI_FUNC rscmwdau_ConfigureSubscriberPrivateUserID(ViSession instrumentHandle,
                                                            ViInt32   IMS,
                                                            ViInt32   subscriber,
                                                            ViString  privateUserID);

ViStatus _VI_FUNC rscmwdau_ConfigureSubscriberAuthentication(ViSession instrumentHandle,
                                                             ViInt32   IMS,
                                                             ViInt32   subscriber,
                                                             ViInt32   authentication);

ViStatus _VI_FUNC rscmwdau_ConfigureSubscriberAuthenticationData(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   subscriber,
                            ViInt32   keyGenerationAlgorithm,
                            ViString  key,
                            ViString  AMF,
                            ViString  OPC,
                            ViInt32   RESLength);

ViStatus _VI_FUNC rscmwdau_ConfigureSubscriberAuthenticationIPSec(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   subscriber,
                            ViBoolean IPSec,
                            ViInt32   integrityAlgorithm,
                            ViInt32   encryptionAlgorithm);

ViStatus _VI_FUNC rscmwdau_ConfigureSubscriberPublicUserIDs(ViSession instrumentHandle,
                                                            ViInt32   IMS,
                                                            ViInt32   subscriber,
                                                            ViInt32   index,
                                                            ViString  publicUserIDs);

ViStatus _VI_FUNC rscmwdau_ConfigureSubscriberQCI(ViSession instrumentHandle,
                                                  ViInt32   IMS,
                                                  ViInt32   subscriber,
                                                  ViInt32   QCI);

ViStatus _VI_FUNC rscmwdau_ConfigureSubscriberPAUHeader(ViSession instrumentHandle,
                                                        ViInt32   IMS,
                                                        ViInt32   subscriber,
                                                        ViInt32   PAUHeader);

ViStatus _VI_FUNC rscmwdau_CreateVirtualSubscriberProfile(ViSession instrumentHandle,
                                                          ViInt32   IMS);

ViStatus _VI_FUNC rscmwdau_DeleteVirtualSubscriberProfile(ViSession instrumentHandle,
                                                          ViInt32   IMS,
                                                          ViInt32   virtualSubscriber);

ViStatus _VI_FUNC rscmwdau_UpdateVirtualSubscriberProfile(ViSession instrumentHandle,
                                                          ViInt32   IMS);

ViStatus _VI_FUNC rscmwdau_QueryVirtualSubscriberCatalog(ViSession instrumentHandle,
                                                         ViInt32   IMS,
                                                         ViInt32   bufferSize,
                                                         ViChar    _VI_FAR catalog[]);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberSettings(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViString  publicUserID,
                            ViInt32   behavior,
                            ViInt32   signalingType);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberVideo(ViSession instrumentHandle,
                                                           ViInt32   IMS,
                                                           ViInt32   virtualSubscriber,
                                                           ViInt32   videoCodec,
                                                           ViString  videoAttributes);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberMediaEndpoint(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   mediaEndpoint);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberForward(ViSession instrumentHandle,
                                                             ViInt32   IMS,
                                                             ViInt32   virtualSubscriber,
                                                             ViString  IPAddress,
                                                             ViInt32   RTPPort,
                                                             ViInt32   CMDPort,
                                                             ViInt32   AMRAlignmentMode);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberAudioboard(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   instance,
                            ViBoolean enableDTXInDL,
                            ViInt32   forceModeNarrowband,
                            ViInt32   forceModeWideband);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberBearer(ViSession instrumentHandle,
                                                            ViInt32   IMS,
                                                            ViInt32   virtualSubscriber,
                                                            ViBoolean bearer);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberAudioCodec(
                            ViSession instrumentHandle,
                            ViInt32   virtualSubscriber,
                            ViInt32   audioCodec);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberForceCodec(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViBoolean force);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberPCAPFile(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViString  fileName);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberSupportedFeatures(
                            ViSession instrumentHandle,
                            ViInt32   virtualSubscriber,
                            ViBoolean videoCall,
                            ViBoolean sessionModeMessaging,
                            ViBoolean standaloneMessaging,
                            ViBoolean fileTransfer);

ViStatus _VI_FUNC rscmwdau_ConfigureAMRVoiceCodec(ViSession instrumentHandle,
                                                  ViInt32   IMS,
                                                  ViInt32   virtualSubscriber,
                                                  ViInt32   AMRType,
                                                  ViInt32   AMRAlignmentMode);

ViStatus _VI_FUNC rscmwdau_ConfigureAMRCodecRates(ViSession instrumentHandle,
                                                  ViInt32   IMS,
                                                  ViInt32   virtualSubscriber,
                                                  ViInt32   codecIndex,
                                                  ViBoolean AMRCodecRates);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberEVSCodec(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   startMode,
                            ViInt32   HFOnly,
                            ViInt32   configurationMode,
                            ViInt32   CMR,
                            ViInt32   CHAW);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberEVSDTX(ViSession instrumentHandle,
                                                            ViInt32   IMS,
                                                            ViInt32   virtualSubscriber,
                                                            ViInt32   DTX,
                                                            ViInt32   DTXRecv);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberEVSBandwidth(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   bandwidthSelect,
                            ViInt32   bandwidth);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberEVSCodecEnable(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   index,
                            ViBoolean codecRate);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberEVSBitrateRange(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   bandwidthSelect,
                            ViInt32   bitrateLower,
                            ViInt32   bitrateHigher);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberEVSIOModeConfig(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   IOMode);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberMTCDestination(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViString  destination);

ViStatus _VI_FUNC rscmwdau_QueryVirtualSubscriberMTCDestinationList(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   bufferSize,
                            ViChar    _VI_FAR destinations[]);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberMTCCallSettings(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   callType,
                            ViInt32   signalingType,
                            ViInt32   AMRType,
                            ViInt32   AMRAlignment);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberMTCAMRCodecRate(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   codecIndex,
                            ViBoolean AMRCodecRates);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberMTCAMRVideoCodec(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   videoCodec,
                            ViString  videoAttributes);

ViStatus _VI_FUNC rscmwdau_InitiateVirtualSubscriberVoiceSettings(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberSMSSettings(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViString  destination,
                            ViInt32   SMSType,
                            ViString  SMSText);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberSMSEncoding(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   encoding);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberGroupChatAddParticipant(
                            ViSession instrumentHandle,
                            ViString  addParticipant);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberGroupChatDeleteParticipant(
                            ViSession instrumentHandle,
                            ViString  deleteParticipant);

ViStatus _VI_FUNC rscmwdau_QueryVirtualSubscriberGroupChatParticipants(
                            ViSession instrumentHandle,
                            ViInt32   bufferSize,
                            ViChar    _VI_FAR participants[]);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberSMSImportFile(
                            ViSession instrumentHandle,
                            ViInt32   virtualSubscriber,
                            ViString  fileName);

ViStatus _VI_FUNC rscmwdau_QueryVirtualSubscriberSMSDestinationList(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   bufferSize,
                            ViChar    _VI_FAR destinations[]);

ViStatus _VI_FUNC rscmwdau_SendVirtualSubscriberSMS(ViSession instrumentHandle,
                                                    ViInt32   IMS,
                                                    ViInt32   virtualSubscriber);

ViStatus _VI_FUNC rscmwdau_QueryVirtualSubscriberFileTransferDestinationList(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   bufferSize,
                            ViChar    _VI_FAR destinationList[]);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberFileTransferType(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViInt32   type);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberFileTransferChunkSize(
                            ViSession instrumentHandle,
                            ViInt32   virtualSubscriber,
                            ViUInt32  chunkSize);

ViStatus _VI_FUNC rscmwdau_ConfigureVirtualSubscriberFileTransfer(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber,
                            ViString  destination,
                            ViString  file);

ViStatus _VI_FUNC rscmwdau_InitiateVirtualSubscriberFileTransfer(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   virtualSubscriber);

ViStatus _VI_FUNC rscmwdau_InitiateUpdateCall(ViSession instrumentHandle,
                                              ViInt32   IMS);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallSettings(ViSession instrumentHandle,
                                                       ViInt32   IMS,
                                                       ViString  callID,
                                                       ViInt32   AMRType,
                                                       ViInt32   AMRAlignment);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallCodec(ViSession instrumentHandle,
                                                    ViInt32   IMS,
                                                    ViInt32   index,
                                                    ViBoolean codecRate,
                                                    ViInt32   videoCodec,
                                                    ViString  videoAttributes,
                                                    ViInt32   callType);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallAudioCodec(ViSession instrumentHandle,
                                                         ViInt32   audioCodec);

ViStatus _VI_FUNC rscmwdau_QueryUpdateCallIDs(ViSession instrumentHandle,
                                              ViInt32   IMS,
                                              ViInt32   bufferSize,
                                              ViChar    _VI_FAR callIDs[]);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallEvent(ViSession instrumentHandle,
                                                    ViInt32   IMS,
                                                    ViInt32   event);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallEVSCodec(ViSession instrumentHandle,
                                                       ViInt32   IMS,
                                                       ViInt32   startMode,
                                                       ViInt32   HFOnly,
                                                       ViInt32   configurationMode,
                                                       ViInt32   CMR,
                                                       ViInt32   CHAW);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallEVSDTX(ViSession instrumentHandle,
                                                     ViInt32   IMS,
                                                     ViInt32   DTX,
                                                     ViInt32   DTXRecv);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallEVSBandwidth(ViSession instrumentHandle,
                                                           ViInt32   IMS,
                                                           ViInt32   bandwidthSelect,
                                                           ViInt32   bandwidth);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallEVSCodecEnable(ViSession instrumentHandle,
                                                             ViInt32   IMS,
                                                             ViInt32   index,
                                                             ViBoolean codecRate);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallEVSBitrateRange(
                            ViSession instrumentHandle,
                            ViInt32   IMS,
                            ViInt32   bandwidthSelect,
                            ViInt32   bitrateLower,
                            ViInt32   bitrateHigher);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallInbandCMRAMR(ViSession instrumentHandle,
                                                           ViInt32   bitrate);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallInbandCMRAMRWB(ViSession instrumentHandle,
                                                             ViInt32   bitrate);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallInbandCMREVSBandwidth(
                            ViSession instrumentHandle,
                            ViInt32   bandwidth);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallInbandCMREVSCodecRate(
                            ViSession instrumentHandle,
                            ViInt32   codeRate);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateCallInbandCMRRepetition(
                            ViSession instrumentHandle,
                            ViInt32   repetition);

ViStatus _VI_FUNC rscmwdau_InitiateUpdateCallInband(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_ConfigureUpdateChatText(ViSession instrumentHandle,
                                                   ViString  updateText);

ViStatus _VI_FUNC rscmwdau_InitiateUpdateChat(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_SendUpdateChatActiveNotification(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_SendUpdateChatIdleNotification(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_QueryIMSEventLog(ViSession instrumentHandle,
                                            ViInt32   IMS,
                                            ViInt32   arraySize,
                                            ViInt32   bufferSize,
                                            ViChar    _VI_FAR ID[],
                                            ViChar    _VI_FAR timestamp[],
                                            ViChar    _VI_FAR source[],
                                            ViChar    _VI_FAR destination[],
                                            ViInt32   _VI_FAR type[],
                                            ViInt32   _VI_FAR status[],
                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryIMSSMSEventHistory(ViSession instrumentHandle,
                                                   ViInt32   IMS,
                                                   ViInt32   arraySize,
                                                   ViInt32   bufferSize,
                                                   ViString  eventID,
                                                   ViChar    _VI_FAR SMSTimestamp[],
                                                   ViInt32   _VI_FAR SMSType[],
                                                   ViInt32   _VI_FAR SMSEncoding[],
                                                   ViChar    _VI_FAR SMSText[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryIMSCALLEventHistory(ViSession instrumentHandle,
                                                    ViInt32   IMS,
                                                    ViInt32   arraySize,
                                                    ViInt32   bufferSize,
                                                    ViString  eventID,
                                                    ViInt32   _VI_FAR historyStatus[],
                                                    ViChar    _VI_FAR historyTimestamp[],
                                                    ViInt32   _VI_FAR signalingType[],
                                                    ViInt32   _VI_FAR AMRType[],
                                                    ViInt32   _VI_FAR AMRAlignmentMode[],
                                                    ViChar    _VI_FAR AMRMode[],
                                                    ViInt32   _VI_FAR videoCodec[],
                                                    ViChar    _VI_FAR videoAttributes[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGServiceState(ViSession instrumentHandle,
                                                     ViInt32   serviceState);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGIPAddress(ViSession instrumentHandle,
                                                  ViString  ePDGIPv4Address,
                                                  ViString  ePDGIPv6Address);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGID(ViSession instrumentHandle,
                                           ViInt32   IDType,
                                           ViString  IDValue);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGInternetKeyExchangeProtocol(
                            ViSession instrumentHandle,
                            ViInt32   encryption,
                            ViInt32   PRF,
                            ViInt32   integrity,
                            ViInt32   diffieHellman);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGEncapsulatingSecurityPayload(
                            ViSession instrumentHandle,
                            ViInt32   encryption,
                            ViInt32   integrity);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGDeadPeerDetectionEnabled(
                            ViSession instrumentHandle,
                            ViBoolean enabled);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGDeadPeerDetection(ViSession instrumentHandle,
                                                          ViInt32   interval,
                                                          ViInt32   timeout);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGSSLCertificate(ViSession instrumentHandle,
                                                       ViBoolean enable,
                                                       ViString  serverKeyFile,
                                                       ViString  serverCertificateFile);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGPCSFIKEv2Auto(ViSession instrumentHandle,
                                                      ViBoolean autoMode);

ViStatus _VI_FUNC rscmwdau_ClearePDGEventLog(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGIMSI(ViSession instrumentHandle,
                                             ViString  IMSI);

ViStatus _VI_FUNC rscmwdau_QueryePDGIMSIConnections(ViSession instrumentHandle,
                                                    ViInt32   arraySize,
                                                    ViChar    _VI_FAR ePDGConnections[]);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGAuthenticationAlgorithm(
                            ViSession instrumentHandle,
                            ViInt32   authenticationAlgorithm);

ViStatus _VI_FUNC rscmwdau_ConfigureePDGAuthenticationDataSettings(
                            ViSession instrumentHandle,
                            ViString  key,
                            ViString  RAND,
                            ViString  AMF,
                            ViInt32   keyType,
                            ViString  authenticationOPc);

ViStatus _VI_FUNC rscmwdau_ConfigureApplicationType(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   applicationType);

ViStatus _VI_FUNC rscmwdau_ConfigureRAN(ViSession instrumentHandle,
                                        ViInt32   instance,
                                        ViString  RANName);

ViStatus _VI_FUNC rscmwdau_RANAssign(ViSession instrumentHandle,
                                     ViInt32   instance,
                                     ViInt32   RAN);

ViStatus _VI_FUNC rscmwdau_ConfigureRANTrace(ViSession instrumentHandle,
                                             ViInt32   instance,
                                             ViInt32   RAN,
                                             ViBoolean uplink,
                                             ViBoolean downlink);

ViStatus _VI_FUNC rscmwdau_QueryRANTraceCatalog(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   bufferSize,
                                                ViChar    _VI_FAR RANName[]);

ViStatus _VI_FUNC rscmwdau_QueryRANCatalog(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   bufferSize,
                                           ViChar    _VI_FAR RANName[]);

ViStatus _VI_FUNC rscmwdau_ConfigurePing(ViSession instrumentHandle,
                                         ViInt32   instance,
                                         ViString  destination,
                                         ViReal64  interval,
                                         ViInt32   payloadSize,
                                         ViInt32   count);

ViStatus _VI_FUNC rscmwdau_ConfigurePingTimeout(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViReal64  timeout);

ViStatus _VI_FUNC rscmwdau_ConfigureThroughputMeasurementPoints(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   points);

ViStatus _VI_FUNC rscmwdau_ConfigureThroughputMaxCount(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   maxCount);

ViStatus _VI_FUNC rscmwdau_ConfigureDNSRequestsMaxIndexCount(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   maxCount);

ViStatus _VI_FUNC rscmwdau_QueryThroughputMeasurementPointsInterval(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViReal64* interval);

ViStatus _VI_FUNC rscmwdau_ConfigureIPLogging(ViSession instrumentHandle,
                                              ViInt32   instance,
                                              ViInt32   loggingInterface,
                                              ViInt32   fileSize,
                                              ViInt32   packetCounter);

ViStatus _VI_FUNC rscmwdau_ConfigureIPLoggingPacketSnapLength(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   packetSnapLength);

ViStatus _VI_FUNC rscmwdau_QueryIPLoggingLogFileName(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   bufferSize,
                                                     ViChar    _VI_FAR logFileName[]);

ViStatus _VI_FUNC rscmwdau_ConfigureThroughputType(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   throughputType);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfState(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViInt32   IPerfInstance,
                                               ViInt32   configure,
                                               ViBoolean clientState);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfTestDuration(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViReal64  testDuration);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfServer(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   server,
                                                ViInt32   protocol,
                                                ViInt32   port);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfClient(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   client,
                                                ViString  destination,
                                                ViInt32   protocol,
                                                ViInt32   port);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfClientParallelConnections(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   client,
                            ViInt32   parallelConnections);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfClientBitRate(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   client,
                                                       ViReal64  bitRate);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfClientReverseModeEnabled(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   client,
                            ViBoolean reverseMode);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfNetworkAddressTranslation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   index,
                            ViInt32   protocol,
                            ViInt32   port);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfNATParallelConnections(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   index,
                            ViInt32   parallelConnections);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfNATBitRate(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   index,
                                                    ViReal64  bitRate);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfSocketBufferSize(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   IPerfInstance,
                                                          ViInt32   configure,
                                                          ViReal64  socketBufferSize);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfPacketSize(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   packetSize);

ViStatus _VI_FUNC rscmwdau_ConfigureIPerfType(ViSession instrumentHandle,
                                              ViInt32   instance,
                                              ViInt32   type);

ViStatus _VI_FUNC rscmwdau_ConfigureNetworkImpairmentsState(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViBoolean globalState);

ViStatus _VI_FUNC rscmwdau_ConfigureNetworkImpairmentsSetState(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   index,
                            ViBoolean used);

ViStatus _VI_FUNC rscmwdau_ConfigureNetworkImpairmentsIPSettings(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   index,
                            ViInt32   direction,
                            ViString  IPAddress,
                            ViInt32   portRangeStart,
                            ViInt32   portRangeStop);

ViStatus _VI_FUNC rscmwdau_ConfigureNetworkImpairmentsDelay(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   index,
                                                            ViReal64  delay,
                                                            ViReal64  jitter,
                                                            ViReal64  reorderingRate);

ViStatus _VI_FUNC rscmwdau_ConfigureNetworkImpairmentsRates(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   index,
                                                            ViReal64  packetlossRate,
                                                            ViReal64  duplicatesRate,
                                                            ViReal64  corruptionRate);

ViStatus _VI_FUNC rscmwdau_ConfigureNetworkImpairmentsJitterDistribution(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   index,
                            ViInt32   jitterDistribution);

ViStatus _VI_FUNC rscmwdau_ConfigureIPAnalysisResults(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   view,
                                                      ViBoolean state);

ViStatus _VI_FUNC rscmwdau_ConfigureIPAnalysisResultsAll(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViBoolean _VI_FAR resultsState[]);

ViStatus _VI_FUNC rscmwdau_ConfigureTCPAnalysisResults(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   type,
                                                       ViReal64  treshold);

ViStatus _VI_FUNC rscmwdau_FTTriggerAssignConnectionToTrace(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   traceIndex,
                                                            ViInt32   flowID);

ViStatus _VI_FUNC rscmwdau_ConfigureApplication(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViString  application);

ViStatus _VI_FUNC rscmwdau_ConfigureLayer(ViSession instrumentHandle,
                                          ViInt32   instance,
                                          ViInt32   layer);

ViStatus _VI_FUNC rscmwdau_ConfigureStoreDatabase(ViSession instrumentHandle,
                                                  ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_QueryIPAnalysisExportFilePath(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   bufferSize,
                                                         ViChar    _VI_FAR filePath[]);

ViStatus _VI_FUNC rscmwdau_ConfigureIPAnalysisPortScan(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViString  destinationIP,
                                                       ViInt32   portStart,
                                                       ViInt32   portStop,
                                                       ViInt32   layer4Protocol,
                                                       ViInt32   timeout);

ViStatus _VI_FUNC rscmwdau_IPAnalysisPortScanClearEventLog(ViSession instrumentHandle,
                                                           ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_IPAnalysisPortScanInitiate(ViSession instrumentHandle,
                                                      ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_IPAnalysisPortScanAbort(ViSession instrumentHandle,
                                                   ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_ConfigureIPAnalysisFlowFilterConnections(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   connections);

ViStatus _VI_FUNC rscmwdau_ConfigureIPAnalysisFlowFilterExtensions(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   filterLines,
                            ViBoolean _VI_FAR enabled[],
                            ViInt32   _VI_FAR type[],
                            ViString  filterString);

ViStatus _VI_FUNC rscmwdau_ConfigureIPAnalysisKeywordImport(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViString  fileName);

ViStatus _VI_FUNC rscmwdau_ConfigureIPAnalysisKeywordAdd(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViString  keyword);

ViStatus _VI_FUNC rscmwdau_ConfigureIPAnalysisKeywordDelete(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViString  keyword);

ViStatus _VI_FUNC rscmwdau_QueryIPAnalysisKeywordList(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   bufferSize,
                                                      ViChar    _VI_FAR list[]);

ViStatus _VI_FUNC rscmwdau_ConfigureIPReplayCreateList(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViString  fileName,
                                                       ViInt32   iteration,
                                                       ViInt32   networkInterface);

ViStatus _VI_FUNC rscmwdau_QueryIPReplayFilesInPlaylist(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   arraySize,
                                                        ViInt32   bufferSize,
                                                        ViChar    _VI_FAR fileName[],
                                                        ViInt32   _VI_FAR iteration[],
                                                        ViInt32   _VI_FAR networkInterface[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ConfigureIPReplayInterface(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViString  fileName,
                                                      ViInt32   networkInterface);

ViStatus _VI_FUNC rscmwdau_QueryIPReplayInterfaces(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32   bufferSize,
                                                   ViChar    _VI_FAR fileName[],
                                                   ViInt32   _VI_FAR networkInterface[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ConfigureIPReplayIteration(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViString  fileName,
                                                      ViInt32   iteration);

ViStatus _VI_FUNC rscmwdau_QueryIPReplayIterations(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32   bufferSize,
                                                   ViChar    _VI_FAR fileName[],
                                                   ViInt32   _VI_FAR iteration[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ConfigureIPReplayStartReplaying(ViSession instrumentHandle,
                                                           ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_ConfigureIPReplayStopReplaying(ViSession instrumentHandle,
                                                          ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_ConfigureIPReplayRemoveAllFilesFromPlaylist(
                            ViSession instrumentHandle,
                            ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_QueryIPReplayProgress(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   arraySize,
                                                 ViInt32   bufferSize,
                                                 ViChar    _VI_FAR fileName[],
                                                 ViInt32   _VI_FAR progress[],
                                                 ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryIPReplayState(ViSession instrumentHandle,
                                              ViInt32   instance,
                                              ViInt32*  state);

ViStatus _VI_FUNC rscmwdau_ConfigureAudioDelayMaximumSamples(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   maximumSamples);

ViStatus _VI_FUNC rscmwdau_QueryAudioDelayIntervals(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32*  interval,
                                                    ViInt32*  samplesPerInterval);

ViStatus _VI_FUNC rscmwdau_ConfigureQoSEnabled(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViBoolean enabled);

ViStatus _VI_FUNC rscmwdau_QoSAddFilter(ViSession instrumentHandle,
                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_QoSRemoveFilter(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   profile);

ViStatus _VI_FUNC rscmwdau_ConfigureQoSProfile(ViSession instrumentHandle,
                                               ViInt32   instance,
                                               ViInt32   profile,
                                               ViBoolean enabled,
                                               ViString  IPAddress,
                                               ViInt32   protocol,
                                               ViBoolean TCPAckPriorization,
                                               ViInt32   hopLimit);

ViStatus _VI_FUNC rscmwdau_ConfigureQoSProfilePortRange(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   profile,
                                                        ViInt32   srcStartPort,
                                                        ViInt32   srcEndPort,
                                                        ViInt32   dstStartPort,
                                                        ViInt32   dstEndPort);

ViStatus _VI_FUNC rscmwdau_ConfigureQoSProfileDelay(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   profile,
                                                    ViReal64  delay,
                                                    ViReal64  jitter,
                                                    ViInt32   jitterDistribution,
                                                    ViReal64  reorderingRate);

ViStatus _VI_FUNC rscmwdau_ConfigureQoSProfileRates(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   profile,
                                                    ViReal64  packetlossRate,
                                                    ViReal64  duplicatesRate,
                                                    ViReal64  corruptionRate,
                                                    ViReal64  maximumBitRate);

ViStatus _VI_FUNC rscmwdau_DataAppMeasInit(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   measurement);

ViStatus _VI_FUNC rscmwdau_DataAppMeasAbort(ViSession instrumentHandle,
                                            ViInt32   instance,
                                            ViInt32   measurement);

ViStatus _VI_FUNC rscmwdau_DataAppMeasStop(ViSession instrumentHandle,
                                           ViInt32   instance,
                                           ViInt32   measurement);

ViStatus _VI_FUNC rscmwdau_QueryDataAppMeasStatus(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   measurement,
                                                  ViInt32*  mainState,
                                                  ViInt32*  syncState,
                                                  ViInt32*  resourcesState);

ViStatus _VI_FUNC rscmwdau_DataApplicationMeasurementAudioDelayInit(
                            ViSession instrumentHandle,
                            ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_DataApplicationMeasurementAudioDelayAbort(
                            ViSession instrumentHandle,
                            ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_DataApplicationMeasurementAudioDelayStop(
                            ViSession instrumentHandle,
                            ViInt32   instance);

ViStatus _VI_FUNC rscmwdau_QueryDataApplicationMeasurementAudioDelayStatus(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32*  mainState);

ViStatus _VI_FUNC rscmwdau_QueryDataApplicationMeasurementAudioDelayAllStatus(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32*  mainState,
                            ViInt32*  syncState,
                            ViInt32*  resourcesState);

ViStatus _VI_FUNC rscmwdau_ReadPingMeasurementResults(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   arraySize,
                                                      ViInt32   bufferSize,
                                                      ViInt32   timeout,
                                                      ViInt32*  reliability,
                                                      ViChar    _VI_FAR timeStamp[],
                                                      ViReal64  _VI_FAR latency[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchPingMeasurementResults(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   arraySize,
                                                       ViInt32   bufferSize,
                                                       ViInt32*  reliability,
                                                       ViChar    _VI_FAR timeStamp[],
                                                       ViReal64  _VI_FAR latency[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchPingNoReplyCount(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32*  noReplyCount);

ViStatus _VI_FUNC rscmwdau_FetchPingStatisticaResults(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32*  reliability,
                                                      ViReal64* minimumPingLatency,
                                                      ViReal64* maximumPingLatency,
                                                      ViReal64* averagePingLatency);

ViStatus _VI_FUNC rscmwdau_ReadIPerfMeasurementThroughputResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   direction,
                            ViInt32   timeout,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR throughput[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchIPerfMeasurementThroughputResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   direction,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR throughput[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchIPerfMeasurementPacketloss(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  _VI_FAR packetloss[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchMeasurementThroughputRANResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   RAN,
                            ViInt32   direction,
                            ViInt32*  reliability,
                            ViReal64* currentThroughput,
                            ViReal64* minimumThroughput,
                            ViReal64* maximumThroughput,
                            ViReal64* averageThroughput);

ViStatus _VI_FUNC rscmwdau_ReadMeasurementThroughputRANResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   RAN,
                            ViInt32   direction,
                            ViInt32   timeout,
                            ViInt32*  reliability,
                            ViReal64* currentThroughput,
                            ViReal64* minimumThroughput,
                            ViReal64* maximumThroughput,
                            ViReal64* averageThroughput);

ViStatus _VI_FUNC rscmwdau_FetchMeasurementThroughputRANTotalResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   direction,
                            ViInt32*  reliability,
                            ViReal64* currentThroughput,
                            ViReal64* minimumThroughput,
                            ViReal64* maximumThroughput,
                            ViReal64* averageThroughput);

ViStatus _VI_FUNC rscmwdau_ReadMeasurementThroughputRANTotalResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   direction,
                            ViInt32   timeout,
                            ViInt32*  reliability,
                            ViReal64* currentThroughput,
                            ViReal64* minimumThroughput,
                            ViReal64* maximumThroughput,
                            ViReal64* averageThroughput);

ViStatus _VI_FUNC rscmwdau_FetchMeasurementThroughputTraceRANResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   RAN,
                            ViInt32   arraySize,
                            ViInt32   direction,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR throughput[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ReadMeasurementThroughputTraceRANResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   RAN,
                            ViInt32   arraySize,
                            ViInt32   direction,
                            ViInt32   timeout,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR throughput[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchIPerfMeasurementAllResults(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  _VI_FAR results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ReadMeasurementOverallThroughputResult(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   direction,
                            ViInt32   resultType,
                            ViInt32   timeout,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR throughput[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchMeasurementOverallThroughputResult(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   direction,
                            ViInt32   resultType,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR throughput[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryNumberOfDNSRequests(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32*  numberOfDNSRequests);

ViStatus _VI_FUNC rscmwdau_QueryDNSRequests(ViSession instrumentHandle,
                                            ViInt32   instance,
                                            ViInt32   arraySize,
                                            ViInt32   bufferSize,
                                            ViInt32*  reliability,
                                            ViChar    _VI_FAR clientIP[],
                                            ViChar    _VI_FAR requestedDomain[],
                                            ViChar    _VI_FAR resolvedIPDomain[],
                                            ViChar    _VI_FAR timestamp[],
                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryTCPAnalysisResults(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32   destinationArraySize,
                                                   ViInt32   flowId,
                                                   ViInt32   _VI_FAR results[],
                                                   ViInt32*  returnedValues,
                                                   ViChar    _VI_FAR destination[]);

ViStatus _VI_FUNC rscmwdau_FetchTCPAnalysisAllResults(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   arraySize,
                                                      ViInt32   destinationArraySize,
                                                      ViInt32*  reliability,
                                                      ViReal64  _VI_FAR results[],
                                                      ViInt32*  returnedValues,
                                                      ViChar    _VI_FAR destination[]);

ViStatus _VI_FUNC rscmwdau_QueryTCPAnalysisDetailResults(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32   bufferSize,
                                                         ViInt32   flowId,
                                                         ViChar    _VI_FAR IPAddressSource[],
                                                         ViChar    _VI_FAR IPAddressDestination[],
                                                         ViReal64  _VI_FAR results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryIPConnectivityStatistics(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32   _VI_FAR results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryIPConnectivityResults(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   arraySize,
                                                      ViInt32   bufferSize,
                                                      ViInt32   flowId,
                                                      ViChar    _VI_FAR layer4Protocol[],
                                                      ViChar    _VI_FAR layer7Protocol[],
                                                      ViChar    _VI_FAR IPAddressSource[],
                                                      ViChar    _VI_FAR IPAddressDestination[],
                                                      ViChar    _VI_FAR application[],
                                                      ViChar    _VI_FAR country[],
                                                      ViReal64  _VI_FAR results[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchIPConnectivityAllResults(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32   bufferSize,
                                                         ViInt32*  reliability,
                                                         ViChar    _VI_FAR IPAddressSource[],
                                                         ViChar    _VI_FAR IPAddressDestination[],
                                                         ViChar    _VI_FAR application[],
                                                         ViChar    _VI_FAR country[],
                                                         ViReal64  _VI_FAR results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryIPConnectivityFeatures(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   bufferSize,
                                                       ViInt32   flowId,
                                                       ViChar    _VI_FAR application[],
                                                       ViChar    _VI_FAR feature[]);

ViStatus _VI_FUNC rscmwdau_FetchDataPerConnectionResults(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32   bufferSize,
                                                         ViInt32*  reliability,
                                                         ViChar    _VI_FAR remoteDestination[],
                                                         ViInt32   _VI_FAR connectionData[],
                                                         ViReal64  _VI_FAR connectionPercentage[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchDataPerProtocolResults(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   arraySize,
                                                       ViInt32   bufferSize,
                                                       ViInt32*  reliability,
                                                       ViChar    _VI_FAR protocol[],
                                                       ViInt32   _VI_FAR protocolData[],
                                                       ViReal64  _VI_FAR protocolPercentage[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchFTTriggerThroughputTrace(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32   traceIndex,
                                                         ViInt32*  reliability,
                                                         ViInt32*  flowID,
                                                         ViReal64  _VI_FAR throughput[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchFTTriggerOpenTrace(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViInt32   _VI_FAR flowID[],
                                                   ViReal64  _VI_FAR timeElapsed[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchFTTriggerCloseTrace(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViInt32   _VI_FAR flowID[],
                                                    ViReal64  _VI_FAR timeElapsed[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchDataPerLayer(ViSession instrumentHandle,
                                             ViInt32   instance,
                                             ViInt32   arraySize,
                                             ViInt32   bufferSize,
                                             ViInt32   layerDepth,
                                             ViInt32*  reliability,
                                             ViChar    _VI_FAR layer[],
                                             ViInt32   _VI_FAR data[],
                                             ViReal64  _VI_FAR percent[],
                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchDataPerApplication(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   arraySize,
                                                   ViInt32   bufferSize,
                                                   ViInt32*  reliability,
                                                   ViChar    _VI_FAR application[],
                                                   ViInt32   _VI_FAR data[],
                                                   ViReal64  _VI_FAR percent[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchIMSAllResults(ViSession instrumentHandle,
                                              ViInt32   instance,
                                              ViInt32   arraySize,
                                              ViInt32*  reliability,
                                              ViReal64  _VI_FAR results[],
                                              ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryIMSFlowInformation(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViInt32   bufferSize,
                                                   ViInt32   callID,
                                                   ViInt32   flowId,
                                                   ViInt32   direction,
                                                   ViInt32   type,
                                                   ViChar    _VI_FAR codec[],
                                                   ViInt32*  sequenceNumber,
                                                   ViInt32*  processedPackets,
                                                   ViInt32*  througput);

ViStatus _VI_FUNC rscmwdau_QueryIMSFlowInformation2(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   bufferSize,
                                                    ViInt32   callID,
                                                    ViInt32   flowId,
                                                    ViInt32   direction,
                                                    ViInt32   type,
                                                    ViChar    _VI_FAR destinationPort[],
                                                    ViChar    _VI_FAR EVSMode[],
                                                    ViChar    _VI_FAR EVSFormat[],
                                                    ViInt32*  EVSPacketsCompact,
                                                    ViInt32*  EVSPacketsFull,
                                                    ViChar    _VI_FAR videoResolution[],
                                                    ViInt32*  videoFrameRate,
                                                    ViChar    _VI_FAR videoOrientation[],
                                                    ViChar    _VI_FAR videoProfile[],
                                                    ViChar    _VI_FAR videoLevel[],
                                                    ViChar    _VI_FAR videoConstraint[]);

ViStatus _VI_FUNC rscmwdau_QueryIMSPacketsMeasurement(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   callID,
                                                      ViInt32*  PERUplink,
                                                      ViInt32*  PERDownlink,
                                                      ViInt32*  DTXUplink,
                                                      ViInt32*  DTXDownlink);

ViStatus _VI_FUNC rscmwdau_QueryIMSJitter(ViSession instrumentHandle,
                                          ViInt32   instance,
                                          ViInt32   callID,
                                          ViInt32*  maximumUplink,
                                          ViInt32*  averageUplink,
                                          ViInt32*  minimumUplink,
                                          ViInt32*  maximumDownlink,
                                          ViInt32*  averageDownlink,
                                          ViInt32*  minimumDownlink);

ViStatus _VI_FUNC rscmwdau_QueryIMSCMR(ViSession instrumentHandle,
                                       ViInt32   instance,
                                       ViInt32   bitrateArraySize,
                                       ViInt32   bandwidthsArraySize,
                                       ViInt32   sessionID,
                                       ViInt32   flowId,
                                       ViInt32   direction,
                                       ViInt32   _VI_FAR bitrates[],
                                       ViInt32   _VI_FAR bandwidths[]);

ViStatus _VI_FUNC rscmwdau_FetchKeywordSearchResults(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   bufferSize,
                                                     ViInt32*  reliability,
                                                     ViChar    _VI_FAR results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchPortScanStatus(ViSession  instrumentHandle,
                                               ViInt32    instance,
                                               ViBoolean* status);

ViStatus _VI_FUNC rscmwdau_FetchPortScanResults(ViSession instrumentHandle,
                                                ViInt32   instance,
                                                ViInt32   bufferSize,
                                                ViInt32*  reliability,
                                                ViChar    _VI_FAR results[],
                                                ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryPortScanEventLog(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   bufferSize,
                                                 ViChar    _VI_FAR results[],
                                                 ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityApplications(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   bufferSize,
                                                     ViChar    _VI_FAR results[]);

ViStatus _VI_FUNC rscmwdau_FetchSecurityAllConnectionsOfSelectedApplication(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   bufferSize,
                            ViString  applicationName,
                            ViInt32*  reliability,
                            ViChar    _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityAllConnectionsOfAllApplication(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   bufferSize,
                            ViInt32*  reliability,
                            ViChar    _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHandshakeVersion(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   bufferSize,
                                                         ViInt32*  reliability,
                                                         ViChar    _VI_FAR versionString[],
                                                         ViInt32*  versionID,
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHandshakeCipherSuites(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   bufferSize,
                            ViInt32   flowID,
                            ViInt32*  reliability,
                            ViChar    _VI_FAR cipherSuiteID[],
                            ViChar    _VI_FAR cipherSuiteName[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHandshakeCompression(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViInt32   bufferSize,
                                                             ViInt32   flowID,
                                                             ViInt32*  reliability,
                                                             ViChar    _VI_FAR compressionID[],
                                                             ViChar    _VI_FAR compressionName[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHashAlgorithms(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   bufferSize,
                                                       ViInt32   flowID,
                                                       ViInt32*  reliability,
                                                       ViChar    _VI_FAR algorithmHashID[],
                                                       ViChar    _VI_FAR algorithmSignID[],
                                                       ViChar    _VI_FAR algorithmHashName[],
                                                       ViChar    _VI_FAR algorithmSignName[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHandshakeElipticCurve(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   bufferSize,
                            ViInt32   flowID,
                            ViInt32*  reliability,
                            ViChar    _VI_FAR elipticCurveID[],
                            ViChar    _VI_FAR elipticCurveName[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHandshakeECPFormat(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   bufferSize,
                                                           ViInt32   flowID,
                                                           ViInt32*  reliability,
                                                           ViChar    _VI_FAR ECPFormatID[],
                                                           ViChar    _VI_FAR ECPFormatName[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHandshakeServer(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   bufferSize,
                                                        ViInt32   flowID,
                                                        ViInt32*  reliability,
                                                        ViChar    _VI_FAR serverID[],
                                                        ViChar    _VI_FAR serverName[],
                                                        ViChar    _VI_FAR serverType[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHandshakeNegotiated(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   bufferSize,
                                                            ViInt32   flowID,
                                                            ViChar    _VI_FAR results[]);

ViStatus _VI_FUNC rscmwdau_FetchSecurityHandshakeNegotiatedECPFormat(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   bufferSize,
                            ViInt32   flowID,
                            ViInt32*  reliability,
                            ViChar    _VI_FAR ECPFormatID[],
                            ViChar    _VI_FAR ECPFormatName[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_QueryIPReplayFileInfo(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViString  fileName,
                                                 ViInt32   bufferSize,
                                                 ViChar    _VI_FAR numberOfPackets[],
                                                 ViChar    _VI_FAR fileSize[],
                                                 ViChar    _VI_FAR bitrate[],
                                                 ViChar    _VI_FAR duration[],
                                                 ViChar    _VI_FAR type[],
                                                 ViChar    _VI_FAR encapsulation[]);

ViStatus _VI_FUNC rscmwdau_QueryIPReplayFileList(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   bufferSize,
                                                 ViChar    _VI_FAR fileList[]);

ViStatus _VI_FUNC rscmwdau_QueryIPReplayAllIPConnections(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32   bufferSize,
                                                         ViString  fileName,
                                                         ViChar    _VI_FAR l4Protocol[],
                                                         ViInt32   _VI_FAR numberOfPackets[],
                                                         ViChar    _VI_FAR sourceAddress[],
                                                         ViChar    _VI_FAR sourcePort[],
                                                         ViChar    _VI_FAR destinationAddress[],
                                                         ViChar    _VI_FAR destinationPort[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ReadAudioDelayMeasurementResults(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   arraySize,
                                                            ViInt32   direction,
                                                            ViInt32*  reliability,
                                                            ViReal64  _VI_FAR results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchAudioDelayMeasurementResults(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViInt32   direction,
                                                             ViInt32*  reliability,
                                                             ViReal64  _VI_FAR results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ReadAudioDelayTimeOfArrivalResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   timeDirection,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchAudioDelayTimeOfArrivalResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   timeDirection,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ReadAudioDelayMeasurementTraceResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   direction,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchAudioDelayMeasurementTraceResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   direction,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_ReadAudioDelayTimeOfArrivalTraceResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   timeDirection,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_FetchAudioDelayTimeOfArrivalTraceResults(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   timeDirection,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwdau_SetAttributeViInt32(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwdau_SetAttributeViReal64(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwdau_SetAttributeViString(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViString  attributeValue);

ViStatus _VI_FUNC rscmwdau_SetAttributeViBoolean(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwdau_SetAttributeViSession(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViSession attributeValue);

ViStatus _VI_FUNC rscmwdau_GetAttributeRepCapName(ViSession instrumentHandle,
                                                  ViUInt32  attributeID,
                                                  ViString  repCapNameID,
                                                  ViInt32   index,
                                                  ViInt32   bufferSize,
                                                  ViChar    _VI_FAR repCapName[]);

ViStatus _VI_FUNC rscmwdau_GetAttributeRepeatedCapabilityIds(ViSession instrumentHandle,
                                                             ViUInt32  attributeID,
                                                             ViInt32   bufferSize,
                                                             ViChar    _VI_FAR repeatedCapabilityId_s[]);

ViStatus _VI_FUNC rscmwdau_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrumentHandle,
                            ViUInt32  attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    _VI_FAR repeatedCapabilityIdName_s[]);

ViStatus _VI_FUNC rscmwdau_GetAttributeViInt32(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViUInt32  attributeID,
                                               ViInt32*  attributeValue);

ViStatus _VI_FUNC rscmwdau_GetAttributeViReal64(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViReal64* attributeValue);

ViStatus _VI_FUNC rscmwdau_GetAttributeViString(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViUInt32  attributeID,
                                                ViInt32   bufferSize,
                                                ViChar    _VI_FAR attributeValue[]);

ViStatus _VI_FUNC rscmwdau_GetAttributeViBoolean(ViSession  instrumentHandle,
                                                 ViString   repeatedCapabilityName,
                                                 ViUInt32   attributeID,
                                                 ViBoolean* attributeValue);

ViStatus _VI_FUNC rscmwdau_GetAttributeViSession(ViSession  instrumentHandle,
                                                 ViString   repeatedCapabilityName,
                                                 ViUInt32   attributeID,
                                                 ViSession* attributeValue);

ViStatus _VI_FUNC rscmwdau_CheckAttributeViInt32(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwdau_CheckAttributeViReal64(ViSession instrumentHandle,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwdau_CheckAttributeViString(ViSession instrumentHandle,
                                                  ViString  repeatedCapabilityName,
                                                  ViUInt32  attributeID,
                                                  ViString  attributeValue);

ViStatus _VI_FUNC rscmwdau_CheckAttributeViBoolean(ViSession instrumentHandle,
                                                   ViString  repeatedCapabilityName,
                                                   ViUInt32  attributeID,
                                                   ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwdau_CheckAttributeViSession(ViSession instrumentHandle,
                                                   ViString  repeatedCapabilityName,
                                                   ViUInt32  attributeID,
                                                   ViSession attributeValue);

ViStatus _VI_FUNC rscmwdau_reset(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_self_test(ViSession instrumentHandle,
                                     ViInt16*  selfTestResult,
                                     ViChar    _VI_FAR selfTestMessage[]);

ViStatus _VI_FUNC rscmwdau_SelfTestResults(ViSession instrumentHandle,
                                           ViInt32   bufferSize,
                                           ViChar    _VI_FAR results[]);

ViStatus _VI_FUNC rscmwdau_revision_query(ViSession instrumentHandle,
                                          ViChar    _VI_FAR instrumentDriverRevision[],
                                          ViChar    _VI_FAR firmwareRevision[]);

ViStatus _VI_FUNC rscmwdau_SystemVersion(ViSession instrumentHandle,
                                         ViInt32   length,
                                         ViChar    _VI_FAR systemVersion[]);

ViStatus _VI_FUNC rscmwdau_error_query(ViSession instrumentHandle,
                                       ViInt32*  errorCode,
                                       ViChar    _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rscmwdau_ErrorList(ViSession instrumentHandle,
                                     ViInt32   bufferSize,
                                     ViChar    _VI_FAR errors[]);

ViStatus _VI_FUNC rscmwdau_error_message(ViSession instrumentHandle,
                                         ViStatus  errorCode,
                                         ViChar    _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rscmwdau_ReliabilityIndicator(ViSession instrumentHandle,
                                                ViInt32   reliabilityCode,
                                                ViChar    _VI_FAR reliabilityMessage[]);

ViStatus _VI_FUNC rscmwdau_SetOPCTimeout(ViSession instrumentHandle,
                                         ViInt32   timeout);

ViStatus _VI_FUNC rscmwdau_GetOPCTimeout(ViSession instrumentHandle,
                                         ViInt32*  timeout);

ViStatus _VI_FUNC rscmwdau_Preset(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_ClearStatus(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_IDQueryResponse(ViSession instrumentHandle,
                                           ViChar    _VI_FAR IDQueryResponse[]);

ViStatus _VI_FUNC rscmwdau_ProcessAllPreviousCommands(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_QueryOPC(ViSession instrumentHandle,
                                    ViInt32*  OPC);

ViStatus _VI_FUNC rscmwdau_SetVISATimeout(ViSession instrumentHandle,
                                          ViUInt32  VISATimeout);

ViStatus _VI_FUNC rscmwdau_GetVISATimeout(ViSession instrumentHandle,
                                          ViUInt32* VISATimeout);

ViStatus _VI_FUNC rscmwdau_ConfigureErrorChecking(ViSession instrumentHandle,
                                                  ViBoolean optionChecking,
                                                  ViBoolean rangeChecking,
                                                  ViBoolean statusChecking);

ViStatus _VI_FUNC rscmwdau_ConfigureAutoSystemErrQuery(ViSession instrumentHandle,
                                                       ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rscmwdau_ConfigureMultiThreadLocking(ViSession instrumentHandle,
                                                       ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rscmwdau_GetError(ViSession instrumentHandle,
                                    ViStatus* code,
                                    ViInt32   bufferSize,
                                    ViChar    _VI_FAR description[]);

ViStatus _VI_FUNC rscmwdau_ClearError(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwdau_ReadToFileFromInstrument(ViSession instrumentHandle,
                                                    ViString  source,
                                                    ViString  destination);

ViStatus _VI_FUNC rscmwdau_WriteFromFileToInstrument(ViSession instrumentHandle,
                                                     ViString  source,
                                                     ViString  destination);

ViStatus _VI_FUNC rscmwdau_WriteInstrData(ViSession instrumentHandle,
                                          ViString  writeBuffer);

ViStatus _VI_FUNC rscmwdau_ReadInstrData(ViSession instrumentHandle,
                                         ViInt32   numberOfBytesToRead,
                                         ViChar    _VI_FAR readBuffer[],
                                         ViUInt32* numBytesRead);

ViStatus _VI_FUNC rscmwdau_QueryViBoolean(ViSession  instrumentHandle,
                                          ViString   command,
                                          ViBoolean* value);

ViStatus _VI_FUNC rscmwdau_QueryViInt32(ViSession instrumentHandle,
                                        ViString  command,
                                        ViInt32*  value);

ViStatus _VI_FUNC rscmwdau_QueryViReal64(ViSession instrumentHandle,
                                         ViString  command,
                                         ViReal64* value);

ViStatus _VI_FUNC rscmwdau_QueryViString(ViSession instrumentHandle,
                                         ViString  command,
                                         ViInt32   bufferSize,
                                         ViChar    _VI_FAR value[]);

ViStatus _VI_FUNC rscmwdau_WriteCommandWithOPCSync(ViSession instrumentHandle,
                                                   ViString  writeBuffer,
                                                   ViUInt32  timeout);

ViStatus _VI_FUNC rscmwdau_QueryWithOPCSync(ViSession instrumentHandle,
                                            ViString  writeBuffer,
                                            ViUInt32  timeout,
                                            ViInt32   bufferSize,
                                            ViChar    _VI_FAR readBuffer[],
                                            ViUInt32* numBytesRead);

ViStatus _VI_FUNC rscmwdau_close(ViSession instrumentHandle);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWDAU_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWDAU_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWDAU_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWDAU_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWDAU_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWDAU_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSCMWDAU_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWDAU_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWDAU_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSCMWDAU_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSCMWDAU_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSCMWDAU_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWDAU_ERROR_CODES_AND_MSGS \
    {RSCMWDAU_WARN_MEASURE_UNCALIBRATED,  RSCMWDAU_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSCMWDAU_WARN_OVER_RANGE,            RSCMWDAU_WARNMSG_OVER_RANGE},\
    {RSCMWDAU_ERROR_INCORRECT_STATE ,   RSCMWDAU_ERRMSG_INCORRECT_STATE },\
    {RSCMWDAU_ERROR_INCORRECT_RESPONSE,     RSCMWDAU_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWDAU_ERROR_MAX_TIME_EXCEEDED,    RSCMWDAU_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWDAU_ERROR_RELIABILITY_INDICATOR, RSCMWDAU_ERRMSG_RELIABILITY_INDICATOR}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWDAU_HEADER */
