/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include <float.h>
#include <math.h>
#include "rscmwdau.h"

#pragma warning( disable : 4152 )

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/

/*****************************************************************************
 * Function: rscmwdau_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rscmwdau_InitAttributes(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    // - Class Driver Identification -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_DESCRIPTION, 0, RSCMWDAU_CLASS_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_PREFIX, 0, RSCMWDAU_CLASS_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_VENDOR, 0, RSCMWDAU_CLASS_DRIVER_VENDOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_REVISION, 0, RSCMWDAU_CLASS_DRIVER_REVISION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSCMWDAU_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSCMWDAU_CLASS_SPEC_MINOR_VERSION));

    // - Driver Identification -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION, 0, RSCMWDAU_SPECIFIC_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_PREFIX, 0, RSCMWDAU_SPECIFIC_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_LOCATOR, 0, RSCMWDAU_SPECIFIC_DRIVER_LOCATOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_VENDOR, 0, RSCMWDAU_SPECIFIC_DRIVER_VENDOR));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSCMWDAU_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSCMWDAU_CLASS_SPEC_MINOR_VERSION));

    // - Driver Capabilities -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSCMWDAU_SUPPORTED_INSTRUMENT_MODELS));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSCMWDAU_GROUP_CAPABILITIES));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSCMWDAU_FUNCTION_CAPABILITIES));

    // - Version Info -
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, RSCMWDAU_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, RSCMWDAU_MINOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, RSCMWDAU_MINOR_MINOR_VERSION));

    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, RSCMWDAU_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, RSCMWDAU_CLASS_SPEC_MINOR_VERSION));

    checkErr(RsCore_SetSpecificDriverRevision(instrSession, RS_ATTR_SPECIFIC_DRIVER_REVISION));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwdau_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rscmwdau_reset function calls this function. The
 *           rscmwdau_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwdau_DefaultInstrSetup(ViSession instrSession)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    // Set all the attributes to the default state. Do not update inherent attributes!
    checkErr(RsCore_ApplyAttributeDefaults(instrSession, VI_FALSE));

    // Init attributes
    checkErr(rscmwdau_InitAttributes(instrSession));

    rsSession->fastSweepInstrument = 0;
    checkErr(RsCore_ResetRegistersEseSre(instrSession));
    checkErr(RsCore_Write(instrSession, ":FORM:BASE ASC,10"));
    checkErr(RsCore_Write(instrSession, ":SYST:DISP:UPD OFF"));
    checkErr(RsCore_QueryViInt32(instrSession, "*OPC?", NULL));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwdau_CheckStatus
 * Purpose:  This function checks the status of the instrument to detect
 *           whether the instrument has encountered an error. This function
 *           is called at the end of most exported driver functions. If the
 *           instrument reports an error, this function returns
 *           RS_ERROR_INSTRUMENT_SPECIFIC. The user can set the
 *           rscmwdau_ATTR_QUERY_INSTRUMENT_STATUS attribute to VI_FALSE to disable this
 *           check and increase execution speed.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwdau_CheckStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    if (RsCore_QueryInstrStatus(instrSession) && !RsCore_Simulating(instrSession))
    {
        checkErr(RsCore_CheckStatus(instrSession, VI_SUCCESS));
    }

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwdau_instanceRepCap
 * Purpose:  This function checks instance repeated capability and
 *           creates proper string.
 *****************************************************************************/
ViStatus rscmwdau_instanceRepCap(ViSession instrSession,
                                 ViInt32   instance,
                                 ViChar    repCap[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
            2, "Instance");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld", instance);

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwdau_QueryMeasStatus
 * Purpose:  This function queries measurement status
 *****************************************************************************/
ViStatus _VI_FUNC rscmwdau_QueryMeasStatus(ViSession instrSession,
                                           ViString  command,
                                           ViInt32*  mainState,
                                           ViInt32*  syncState,
                                           ViInt32*  resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   response [RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViString mainStateArr[] = {"OFF","RDY","RUN",NULL};
    ViString syncStateArr[] = {"PEND","ADJ","INV",NULL};
    ViString resStateArr[] = {"QUE","ACT","INV",NULL};

    checkErr(RsCore_QueryViString(instrSession, command, response));

    p2buf = strtok (response, ",");
    if (p2buf == NULL)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;
    *mainState = RsCore_FindStringIndex(mainStateArr,p2buf);
    if (*mainState < 0)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;

    p2buf = strtok (NULL, ",");
    if (p2buf == NULL)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;
    *syncState = RsCore_FindStringIndex(syncStateArr,p2buf);
    if (*syncState < 0)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;

    p2buf = strtok (NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;
    *resourcesState = RsCore_FindStringIndex(resStateArr,p2buf);
    if (*resourcesState < 0)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwdau_QueryMeasMainStatus
 * Purpose:  This function queries measurement main status
 *****************************************************************************/
 ViStatus _VI_FUNC rscmwdau_QueryMeasMainStatus(ViSession instrSession,
                                               ViString  command,
                                               ViInt32*  mainState)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViString mainStateArr[] = {"OFF","RDY","RUN",NULL};

    checkErr(RsCore_QueryViString(instrSession, command, response));

    p2buf = strtok (response, ",");
    if (p2buf == NULL)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;
    *mainState = RsCore_FindStringIndex(mainStateArr,p2buf);
    if (*mainState < 0)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwdau_strCode
 * Purpose:  This function converts a string to int enumeration value.
 *****************************************************************************/
ViInt32 rscmwdau_strCode(ViChar *pBuffer, ViString arrayCodes[])
{
   ViInt32 nIndex = 0;
   ViString pCode = arrayCodes[nIndex];

   while ( pCode != NULL )
   {
      ViChar *pPos = strstr(pBuffer, pCode);
      if ( pPos != NULL )
      {
         return nIndex;
      }
      nIndex++;

      pCode = arrayCodes[nIndex];
   }

   return -1;
}

/*****************************************************************************
 * Function: rscmwdau_doubleQuotedString_WriteCallback
 * Purpose:  This function overrides standard calback funtion. Writes string
 *           with apostrophes
 *****************************************************************************/
ViStatus rscmwdau_doubleQuotedString_WriteCallback(ViSession          instrSession,
                                                   ViConstString      repCapName,
                                                   RsCoreAttributePtr attr,
                                                   void               *value)
{
    return RsCore_SpecialCallback_SurroundParamWrite(instrSession, repCapName, attr, " \"", value, "\"");
}

/*****************************************************************************
 * Function: rscmwdau_GetPingResults
 * Purpose:  This function queries ping results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwdau_GetPingResults(ViSession instrSession,
                                          ViString  command,
                                          ViInt32   timeout,
                                          ViInt32   arraySize,
                                          ViInt32   bufferSize,
                                          ViInt32*  reliability,
                                          ViChar    timeStamp[],
                                          ViReal64  latency[],
                                          ViInt32   *returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf=NULL;
    ViChar*  p2buf;
    size_t   length=0;
    ViInt32  i = 0;

    if (timeout != 0)
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, command, timeout, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, command, &ext_buf));
    }

    p2buf = strtok (ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWDAU_ERROR_INCORRECT_RESPONSE;

    if (reliability != NULL)
        *reliability = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok (NULL, ",\n");

    while (p2buf != NULL && i < arraySize)
    {
        p2buf = strtok (NULL, ",\n"); //throw out the Request number

        if((bufferSize - length) > 0)
        {
            strncat (timeStamp, p2buf, bufferSize - 1 - length);
            length = strlen(timeStamp);
            if((bufferSize - 1 - length) > 0)
            {
                strcat(timeStamp, ",");
                length++;
            }
        }

        p2buf = strtok (NULL, ",\n");
        latency[i] = RsCore_Convert_String_To_ViReal64(p2buf);

        i++;
    }
    if (timeStamp[strlen(p2buf)] == ',') timeStamp[strlen(p2buf)] = 0;

    if (returnedValues) *returnedValues=i;

    checkErr(rscmwdau_CheckStatus(instrSession));

Error:
    if (ext_buf)
        free (ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwdau_GetMeas
 * Purpose:  This function queries measurement data preceeded by reliability indicator
 * The data can be Binary or ASCII format. In case of binary format, they are interpreted as Float32
 *****************************************************************************/
ViStatus _VI_FUNC rscmwdau_GetMeasResults(ViSession instrSession,
                                          ViString  command,
                                          ViInt32   timeout,
                                          ViInt32   arraySize,
                                          ViInt32*  reliability,
                                          ViReal64  result[],
                                          ViInt32   *returnedValues)
{
    ViStatus  error = VI_SUCCESS;
    ViInt32   dataSize;
    ViAReal64 data = NULL;
    ViChar    asciiPart[RS_MAX_SHORT_MESSAGE_BUF_SIZE + 1];

    if (timeout != 0)
    {
        checkErr(RsCore_QueryMixedFloatArrayWithOpc(instrSession, command, RS_MAX_SHORT_MESSAGE_BUF_SIZE, ',', asciiPart, timeout, &data, &dataSize));
    }
    else
    {
        checkErr(RsCore_QueryMixedFloatArray(instrSession, command, RS_MAX_SHORT_MESSAGE_BUF_SIZE, ',', asciiPart, &data, &dataSize));
    }

    if (reliability != NULL)
        *reliability = RsCore_Convert_String_To_ViInt32(asciiPart);

    checkErr(rscmwdau_CheckStatus(instrSession));

    if (dataSize == 0)
    {
        checkErr(RsCore_SetErrorInfo(instrSession, VI_TRUE, RSCMWDAU_ERROR_INCORRECT_RESPONSE, VI_SUCCESS, "Incorrect response to a measurement query"));
    }

    if (returnedValues)
        *returnedValues = dataSize;

    checkErr(RsCore_CopyToUserBufferViReal64Array(result, arraySize, data, dataSize));

Error:
    if (data)
        free(data);

    return error;
}

/*****************************************************************************
 * Function: rscmwdau_stringToHex_ReadCallback
 * Purpose:  This function overrides standard calback funtion.
 *****************************************************************************/
ViStatus rscmwdau_stringToHex_ReadCallback(ViSession          instrSession,
                                           ViConstString      repCapName,
                                           RsCoreAttributePtr attr)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *cmd = NULL,

                *value          = NULL,
                *buffer         = NULL;

    // Build the command string
   checkErr(RsCore_BuildAttrCommandString(instrSession, attr, repCapName, &cmd));

   // --- Attribute data type is used for VISA I/O ---
    switch (attr -> dataType)
    {
        case RS_VAL_STRING:
            checkErr(RsCore_QueryAttributeCommandUnknownLength(instrSession, attr, cmd, &buffer, NULL));
            value = (ViChar*) malloc (strlen(buffer));
            sscanf (buffer, "#H%s", value);
            checkErr(RsCore_SetAttributeP2Value(instrSession, attr, value));
            break;
        default:
            checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, NULL));
    }

Error:
    if (buffer)
        free (buffer);

    if (cmd)
        free (cmd);

    if (value)
        free (value);

    return error;
}

/*****************************************************************************
 * Function: rscmwdau_stringToHex_WriteCallback
 * Purpose:  This function overrides standard calback funtion.
 *****************************************************************************/
ViStatus rscmwdau_stringToHex_WriteCallback(ViSession          instrSession,
                                            ViConstString      repCapName,
                                            RsCoreAttributePtr attr,
                                            void               *value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *cmd = NULL;
    ViChar   *buf = NULL;

    // Build the command string
    checkErr(RsCore_BuildAttrCommandString(instrSession, attr, repCapName, &cmd));
    buf = (ViChar*) malloc (strlen (cmd) + strlen ((ViString) value) + 2);
    switch (attr -> dataType)
    {
        case RS_VAL_STRING:
            sprintf(buf, "%s #H%s", cmd, (ViString) value);
            checkErr(RsCore_WriteAttributeCommand(instrSession, attr, buf));
            break;
        default:
            checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, NULL));
    }

Error:
    if (buf)
        free (buf);

    if (cmd) free (cmd);

    return error;
}

